@@ -50,11 +50,11 @@ protected:
 
 class ActiveNamer : public ActiveBaseVisitor {
 private:
-    typedef std::map<string,AstActive*> ActiveNameMap;
+    typedef std::map<string, AstActive*> ActiveNameMap;
     // STATE
-    AstScope*   m_scopep;               // Current scope to add statement to
-    AstActive*  m_iActivep;             // For current scope, the IActive we're building
-    AstActive*  m_cActivep;             // For current scope, the SActive(combo) we're building
+    AstScope* m_scopep;  // Current scope to add statement to
+    AstActive* m_iActivep;  // For current scope, the IActive we're building
+    AstActive* m_cActivep;  // For current scope, the SActive(combo) we're building
 
     SenTreeSet m_activeSens;  // Sen lists for each active we've made
     typedef vl_unordered_map<AstSenTree*, AstActive*> ActiveMap;
@@ -89,8 +89,7 @@ public:
     AstActive* getCActive(FileLine* fl) {
         if (!m_cActivep) {
             m_cActivep = new AstActive(
-                fl, "combo",
-                new AstSenTree(fl, new AstSenItem(fl, AstSenItem::Combo())));
+                fl, "combo", new AstSenTree(fl, new AstSenItem(fl, AstSenItem::Combo())));
             m_cActivep->sensesStorep(m_cActivep->sensesp());
             addActive(m_cActivep);
         }
@@ -99,8 +98,7 @@ public:
     AstActive* getIActive(FileLine* fl) {
         if (!m_iActivep) {
             m_iActivep = new AstActive(
-                fl, "initial",
-                new AstSenTree(fl, new AstSenItem(fl, AstSenItem::Initial())));
+                fl, "initial", new AstSenTree(fl, new AstSenItem(fl, AstSenItem::Initial())));
             m_iActivep->sensesStorep(m_iActivep->sensesp());
             addActive(m_iActivep);
         }
@@ -122,7 +120,7 @@ public:
             AstSenTree* newsenp = sensesp->cloneTree(false);
             activep = new AstActive(fl, "sequent", newsenp);
             activep->sensesStorep(activep->sensesp());
-            UINFO(8,"    New ACTIVE "<<activep<<endl);
+            UINFO(8, "    New ACTIVE " << activep << endl);
             // Form the sensitivity list
             addActive(activep);
             m_activeMap[newsenp] = activep;
@@ -131,6 +129,7 @@ public:
         }
         return activep;
     }
+
 public:
     // CONSTRUCTORS
     ActiveNamer() {
@@ -139,9 +138,7 @@ public:
         m_cActivep = NULL;
     }
     virtual ~ActiveNamer() {}
-    void main(AstScope* nodep) {
-        iterate(nodep);
-    }
+    void main(AstScope* nodep) { iterate(nodep); }
 };
 
 //######################################################################
@@ -150,27 +147,29 @@ public:
 class ActiveDlyVisitor : public ActiveBaseVisitor {
 public:
     enum CheckType { CT_SEQ, CT_COMBO, CT_INITIAL, CT_LATCH };
+
 private:
-    CheckType   m_check;        // Combo logic or other
-    AstNode*    m_alwaysp;      // Always we're under
-    AstNode*    m_assignp;      // In assign
+    CheckType m_check;  // Combo logic or other
+    AstNode* m_alwaysp;  // Always we're under
+    AstNode* m_assignp;  // In assign
     // VISITORS
     virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         if (m_check != CT_SEQ) {
             // Convert to a non-delayed assignment
-            UINFO(5,"    ASSIGNDLY "<<nodep<<endl);
+            UINFO(5, "    ASSIGNDLY " << nodep << endl);
             if (m_check == CT_INITIAL) {
                 nodep->v3warn(INITIALDLY, "Delayed assignments (<=) in initial or final block\n"
-                              <<nodep->warnMore()<<"... Suggest blocking assignments (=)");
+                                              << nodep->warnMore()
+                                              << "... Suggest blocking assignments (=)");
             } else if (m_check == CT_LATCH) {
                 // Suppress. Shouldn't matter that the interior of the latch races
             } else {
                 nodep->v3warn(COMBDLY, "Delayed assignments (<=) in non-clocked"
-                              " (non flop or latch) block\n"
-                              <<nodep->warnMore()<<"... Suggest blocking assignments (=)");
+                                       " (non flop or latch) block\n"
+                                           << nodep->warnMore()
+                                           << "... Suggest blocking assignments (=)");
             }
-            AstNode* newp = new AstAssign(nodep->fileline(),
-                                          nodep->lhsp()->unlinkFrBack(),
+            AstNode* newp = new AstAssign(nodep->fileline(), nodep->lhsp()->unlinkFrBack(),
                                           nodep->rhsp()->unlinkFrBack());
             nodep->replaceWith(newp);
             VL_DO_DANGLING(nodep->deleteTree(), nodep);
@@ -186,17 +185,18 @@ private:
     }
     virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         AstVar* varp = nodep->varp();
-        if (m_check == CT_SEQ
-            && m_assignp
-            && !varp->isUsedLoopIdx()  // Ignore loop indices
+        if (m_check == CT_SEQ && m_assignp && !varp->isUsedLoopIdx()  // Ignore loop indices
             && !varp->isTemp()) {
             // Allow turning off warnings on the always, or the variable also
             if (!m_alwaysp->fileline()->warnIsOff(V3ErrorCode::BLKSEQ)
                 && !m_assignp->fileline()->warnIsOff(V3ErrorCode::BLKSEQ)
                 && !varp->fileline()->warnIsOff(V3ErrorCode::BLKSEQ)) {
-                m_assignp->v3warn(BLKSEQ, "Blocking assignments (=) in sequential (flop or latch) block\n"
-                                  <<m_assignp->warnMore()<<"... Suggest delayed assignments (<=)");
-                m_alwaysp->fileline()->modifyWarnOff(V3ErrorCode::BLKSEQ, true);  // Complain just once for the entire always
+                m_assignp->v3warn(BLKSEQ,
+                                  "Blocking assignments (=) in sequential (flop or latch) block\n"
+                                      << m_assignp->warnMore()
+                                      << "... Suggest delayed assignments (<=)");
+                m_alwaysp->fileline()->modifyWarnOff(
+                    V3ErrorCode::BLKSEQ, true);  // Complain just once for the entire always
                 varp->fileline()->modifyWarnOff(V3ErrorCode::BLKSEQ, true);
             }
         }
@@ -225,15 +225,15 @@ private:
     //   AstNode::user4()               Used by V3Const::constify, called below
 
     // STATE
-    ActiveNamer m_namer;        // Tracking of active names
-    AstCFunc*   m_scopeFinalp;  // Final function for this scope
-    bool        m_itemCombo;    // Found a SenItem combo
-    bool        m_itemSequent;  // Found a SenItem sequential
+    ActiveNamer m_namer;  // Tracking of active names
+    AstCFunc* m_scopeFinalp;  // Final function for this scope
+    bool m_itemCombo;  // Found a SenItem combo
+    bool m_itemSequent;  // Found a SenItem sequential
 
     // VISITORS
     virtual void visit(AstScope* nodep) VL_OVERRIDE {
         // Create required actives and add to scope
-        UINFO(4," SCOPE   "<<nodep<<endl);
+        UINFO(4, " SCOPE   " << nodep << endl);
         // Clear last scope's names, and collect this scope's existing names
         m_namer.main(nodep);
         m_scopeFinalp = NULL;
@@ -244,48 +244,47 @@ private:
     }
     virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         // Relink to IACTIVE, unless already under it
-        UINFO(4,"    INITIAL "<<nodep<<endl);
-        ActiveDlyVisitor dlyvisitor (nodep, ActiveDlyVisitor::CT_INITIAL);
+        UINFO(4, "    INITIAL " << nodep << endl);
+        ActiveDlyVisitor dlyvisitor(nodep, ActiveDlyVisitor::CT_INITIAL);
         AstActive* wantactivep = m_namer.getIActive(nodep->fileline());
         nodep->unlinkFrBack();
         wantactivep->addStmtsp(nodep);
     }
     virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {
         // Relink to CACTIVE, unless already under it
-        UINFO(4,"    ASSIGNW "<<nodep<<endl);
+        UINFO(4, "    ASSIGNW " << nodep << endl);
         AstActive* wantactivep = m_namer.getCActive(nodep->fileline());
         nodep->unlinkFrBack();
         wantactivep->addStmtsp(nodep);
     }
     virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         // Relink to CACTIVE, unless already under it
-        UINFO(4,"    ASSIGNW "<<nodep<<endl);
+        UINFO(4, "    ASSIGNW " << nodep << endl);
         AstActive* wantactivep = m_namer.getCActive(nodep->fileline());
         nodep->unlinkFrBack();
         wantactivep->addStmtsp(nodep);
     }
     virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
         // Relink to CACTIVE, unless already under it
-        UINFO(4,"    COVERTOGGLE "<<nodep<<endl);
+        UINFO(4, "    COVERTOGGLE " << nodep << endl);
         AstActive* wantactivep = m_namer.getCActive(nodep->fileline());
         nodep->unlinkFrBack();
         wantactivep->addStmtsp(nodep);
     }
     virtual void visit(AstFinal* nodep) VL_OVERRIDE {
         // Relink to CFUNC for the final
-        UINFO(4,"    FINAL "<<nodep<<endl);
+        UINFO(4, "    FINAL " << nodep << endl);
         if (!nodep->bodysp()) {  // Empty, Kill it.
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
             return;
         }
-        ActiveDlyVisitor dlyvisitor (nodep, ActiveDlyVisitor::CT_INITIAL);
+        ActiveDlyVisitor dlyvisitor(nodep, ActiveDlyVisitor::CT_INITIAL);
         if (!m_scopeFinalp) {
             m_scopeFinalp = new AstCFunc(
-                nodep->fileline(), "_final_"+m_namer.scopep()->nameDotless(),
-                m_namer.scopep());
+                nodep->fileline(), "_final_" + m_namer.scopep()->nameDotless(), m_namer.scopep());
             m_scopeFinalp->argTypes(EmitCBaseVisitor::symClassVar());
             m_scopeFinalp->addInitsp(
-                new AstCStmt(nodep->fileline(), EmitCBaseVisitor::symTopAssign()+"\n"));
+                new AstCStmt(nodep->fileline(), EmitCBaseVisitor::symTopAssign() + "\n"));
             m_scopeFinalp->dontCombine(true);
             m_scopeFinalp->formCallTree(true);
             m_scopeFinalp->slow(true);
@@ -300,9 +299,7 @@ private:
     // METHODS
     void visitAlways(AstNode* nodep, AstSenTree* oldsensesp, VAlwaysKwd kwd) {
         // Move always to appropriate ACTIVE based on its sense list
-        if (oldsensesp
-            && oldsensesp->sensesp()
-            && VN_IS(oldsensesp->sensesp(), SenItem)
+        if (oldsensesp && oldsensesp->sensesp() && VN_IS(oldsensesp->sensesp(), SenItem)
             && VN_CAST(oldsensesp->sensesp(), SenItem)->isNever()) {
             // Never executing.  Kill it.
             UASSERT_OBJ(!oldsensesp->sensesp()->nextp(), nodep,
@@ -318,10 +315,11 @@ private:
         bool combo = m_itemCombo;
         bool sequent = m_itemSequent;
 
-        if (!combo && !sequent) combo=true;  // If no list, Verilog 2000: always @ (*)
+        if (!combo && !sequent) combo = true;  // If no list, Verilog 2000: always @ (*)
         if (combo && sequent) {
             if (!v3Global.opt.bboxUnsup()) {
-                nodep->v3error("Unsupported: Mixed edge (pos/negedge) and activity (no edge) sensitive activity list");
+                nodep->v3error("Unsupported: Mixed edge (pos/negedge) and activity "
+                               "(no edge) sensitive activity list");
             }
             sequent = false;
         }
@@ -336,8 +334,9 @@ private:
             // always (posedge RESET) { if (RESET).... }  we know RESET is true.
             // Summarize a long list of combo inputs as just "combo"
 #ifndef __COVERITY__  // Else dead code on next line.
-            if (combo) oldsensesp->addSensesp
-                           (new AstSenItem(nodep->fileline(), AstSenItem::Combo()));
+            if (combo) {
+                oldsensesp->addSensesp(new AstSenItem(nodep->fileline(), AstSenItem::Combo()));
+            }
 #endif
             wantactivep = m_namer.getActive(nodep->fileline(), oldsensesp);
         }
@@ -354,19 +353,18 @@ private:
         // Warn and/or convert any delayed assignments
         if (combo && !sequent) {
             if (kwd == VAlwaysKwd::ALWAYS_LATCH) {
-                ActiveDlyVisitor dlyvisitor (nodep, ActiveDlyVisitor::CT_LATCH);
+                ActiveDlyVisitor dlyvisitor(nodep, ActiveDlyVisitor::CT_LATCH);
             } else {
-                ActiveDlyVisitor dlyvisitor (nodep, ActiveDlyVisitor::CT_COMBO);
+                ActiveDlyVisitor dlyvisitor(nodep, ActiveDlyVisitor::CT_COMBO);
             }
-        }
-        else if (!combo && sequent) {
-            ActiveDlyVisitor dlyvisitor (nodep, ActiveDlyVisitor::CT_SEQ);
+        } else if (!combo && sequent) {
+            ActiveDlyVisitor dlyvisitor(nodep, ActiveDlyVisitor::CT_SEQ);
         }
     }
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // Move always to appropriate ACTIVE based on its sense list
-        UINFO(4,"    ALW   "<<nodep<<endl);
-        //if (debug()>=9) nodep->dumpTree(cout, "  Alw: ");
+        UINFO(4, "    ALW   " << nodep << endl);
+        // if (debug() >= 9) nodep->dumpTree(cout, "  Alw: ");
 
         if (!nodep->bodysp()) {
             // Empty always.  Kill it.
@@ -377,19 +375,29 @@ private:
     }
     virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
         // Move always to appropriate ACTIVE based on its sense list
-        UINFO(4,"    ALWPub   "<<nodep<<endl);
-        //if (debug()>=9) nodep->dumpTree(cout, "  Alw: ");
+        UINFO(4, "    ALWPub   " << nodep << endl);
+        // if (debug() >= 9) nodep->dumpTree(cout, "  Alw: ");
         visitAlways(nodep, nodep->sensesp(), VAlwaysKwd::ALWAYS);
     }
     virtual void visit(AstSenGate* nodep) VL_OVERRIDE {
         AstSenItem* subitemp = nodep->sensesp();
         UASSERT_OBJ(subitemp->edgeType() == VEdgeType::ET_ANYEDGE
-                    || subitemp->edgeType() == VEdgeType::ET_POSEDGE
-                    || subitemp->edgeType() == VEdgeType::ET_NEGEDGE,
+                        || subitemp->edgeType() == VEdgeType::ET_POSEDGE
+                        || subitemp->edgeType() == VEdgeType::ET_NEGEDGE,
                     nodep, "Strange activity type under SenGate");
         iterateChildren(nodep);
     }
     virtual void visit(AstSenItem* nodep) VL_OVERRIDE {
+        if (nodep->varrefp()) {
+            if (AstBasicDType* basicp = nodep->varrefp()->dtypep()->basicp()) {
+                if (basicp->isEventValue()) {
+                    // Events need to be treated as active high so we only activate on event being
+                    // 1
+                    UINFO(8, "Demote event to HIGHEDGE " << nodep << endl);
+                    nodep->edgeType(VEdgeType::ET_HIGHEDGE);
+                }
+            }
+        }
         if (nodep->edgeType() == VEdgeType::ET_ANYEDGE) {
             m_itemCombo = true;
             // Delete the sensitivity
@@ -399,7 +407,7 @@ private:
             // V3LinkResolve should have cleaned most of these up
             if (!nodep->varrefp()->width1()) {
                 nodep->v3error("Unsupported: Non-single bit wide signal pos/negedge sensitivity: "
-                               <<nodep->varrefp()->prettyNameQ());
+                               << nodep->varrefp()->prettyNameQ());
             }
             m_itemSequent = true;
             nodep->varrefp()->varp()->usedClock(true);
@@ -426,9 +434,7 @@ public:
 // Active class functions
 
 void V3Active::activeAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        ActiveVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { ActiveVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("active", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
