@@ -45,9 +45,9 @@
 #include <algorithm>
 #include <cstdarg>
 
-#define CASE_OVERLAP_WIDTH 16           // Maximum width we can check for overlaps in
-#define CASE_BARF          999999       // Magic width when non-constant
-#define CASE_ENCODER_GROUP_DEPTH 8      // Levels of priority to be ORed together in top IF tree
+#define CASE_OVERLAP_WIDTH 16  // Maximum width we can check for overlaps in
+#define CASE_BARF 999999  // Magic width when non-constant
+#define CASE_ENCODER_GROUP_DEPTH 8  // Levels of priority to be ORed together in top IF tree
 
 //######################################################################
 
@@ -64,8 +64,8 @@ private:
         }
         // Detect multiple defaults
         bool hitDefault = false;
-        for (AstCaseItem* itemp = nodep->itemsp();
-             itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
+        for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+             itemp = VN_CAST(itemp->nextp(), CaseItem)) {
             if (itemp->isDefault()) {
                 if (hitDefault) {
                     itemp->v3error("Multiple default statements in case statement.");
@@ -78,8 +78,8 @@ private:
         {
             m_caseExprp = nodep;
             iterate(nodep->exprp());
-            for (AstCaseItem* itemp = nodep->itemsp();
-                 itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
+            for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+                 itemp = VN_CAST(itemp->nextp(), CaseItem)) {
                 iterateAndNextNull(itemp->condsp());
             }
             m_caseExprp = NULL;
@@ -89,16 +89,20 @@ private:
         // See also neverItem
         if (m_caseExprp && nodep->num().isFourState()) {
             if (VN_IS(m_caseExprp, GenCase)) {
-                nodep->v3error("Use of x/? constant in generate case statement, (no such thing as 'generate casez')");
+                nodep->v3error("Use of x/? constant in generate case statement, "
+                               "(no such thing as 'generate casez')");
             } else if (VN_IS(m_caseExprp, Case) && VN_CAST(m_caseExprp, Case)->casex()) {
                 // Don't sweat it, we already complained about casex in general
-            } else if (VN_IS(m_caseExprp, Case) && (VN_CAST(m_caseExprp, Case)->casez()
-                                                   || VN_CAST(m_caseExprp, Case)->caseInside())) {
+            } else if (VN_IS(m_caseExprp, Case)
+                       && (VN_CAST(m_caseExprp, Case)->casez()
+                           || VN_CAST(m_caseExprp, Case)->caseInside())) {
                 if (nodep->num().isUnknown()) {
-                    nodep->v3warn(CASEWITHX, "Use of x constant in casez statement, (perhaps intended ?/z in constant)");
+                    nodep->v3warn(CASEWITHX, "Use of x constant in casez statement, "
+                                             "(perhaps intended ?/z in constant)");
                 }
             } else {
-                nodep->v3warn(CASEWITHX, "Use of x/? constant in case statement, (perhaps intended casex/casez)");
+                nodep->v3warn(CASEWITHX, "Use of x/? constant in case statement, "
+                                         "(perhaps intended casex/casez)");
             }
         }
     }
@@ -121,17 +125,18 @@ private:
     // NODE STATE
     // Cleared each Case
     //  AstIf::user3()          -> bool.  Set true to indicate clone not needed
-    AstUser3InUse       m_inuser3;
+    AstUser3InUse m_inuser3;
 
     // STATE
     VDouble0 m_statCaseFast;  // Statistic tracking
     VDouble0 m_statCaseSlow;  // Statistic tracking
 
     // Per-CASE
-    int         m_caseWidth;    // Width of valueItems
-    int         m_caseItems;    // Number of caseItem unique values
-    bool        m_caseNoOverlapsAllCovered;     // Proven to be synopsys parallel_case compliant
-    AstNode*    m_valueItem[1<<CASE_OVERLAP_WIDTH];  // For each possible value, the case branch we need
+    int m_caseWidth;  // Width of valueItems
+    int m_caseItems;  // Number of caseItem unique values
+    bool m_caseNoOverlapsAllCovered;  // Proven to be synopsys parallel_case compliant
+    // For each possible value, the case branch we need
+    AstNode* m_valueItem[1 << CASE_OVERLAP_WIDTH];
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -141,9 +146,9 @@ private:
         bool opaque = false;
         m_caseItems = 0;
         m_caseNoOverlapsAllCovered = true;
-        for (AstCaseItem* itemp = nodep->itemsp();
-             itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
-            for (AstNode* icondp = itemp->condsp(); icondp!=NULL; icondp=icondp->nextp()) {
+        for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+             itemp = VN_CAST(itemp->nextp(), CaseItem)) {
+            for (AstNode* icondp = itemp->condsp(); icondp; icondp = icondp->nextp()) {
                 if (icondp->width() > width) width = icondp->width();
                 if (icondp->isDouble()) opaque = true;
                 if (!VN_IS(icondp, Const)) width = CASE_BARF;  // Can't parse; not a constant
@@ -151,38 +156,39 @@ private:
             }
         }
         m_caseWidth = width;
-        if (width==0 || width > CASE_OVERLAP_WIDTH || opaque) {
+        if (width == 0 || width > CASE_OVERLAP_WIDTH || opaque) {
             m_caseNoOverlapsAllCovered = false;
             return false;  // Too wide for analysis
         }
-        UINFO(8,"Simple case statement: "<<nodep<<endl);
+        UINFO(8, "Simple case statement: " << nodep << endl);
         // Zero list of items for each value
-        for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) m_valueItem[i] = NULL;
+        for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) m_valueItem[i] = NULL;
         // Now pick up the values for each assignment
         // We can cheat and use uint32_t's because we only support narrow case's
         bool bitched = false;
-        for (AstCaseItem* itemp = nodep->itemsp();
-             itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
-            for (AstNode* icondp = itemp->condsp(); icondp!=NULL; icondp=icondp->nextp()) {
-                //if (debug()>=9) icondp->dumpTree(cout, " caseitem: ");
+        for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+             itemp = VN_CAST(itemp->nextp(), CaseItem)) {
+            for (AstNode* icondp = itemp->condsp(); icondp; icondp = icondp->nextp()) {
+                // if (debug() >= 9) icondp->dumpTree(cout, " caseitem: ");
                 AstConst* iconstp = VN_CAST(icondp, Const);
                 UASSERT_OBJ(iconstp, nodep, "above 'can't parse' should have caught this");
                 if (neverItem(nodep, iconstp)) {
                     // X in casez can't ever be executed
                 } else {
-                    V3Number nummask (itemp, iconstp->width());
+                    V3Number nummask(itemp, iconstp->width());
                     nummask.opBitsNonX(iconstp->num());
                     uint32_t mask = nummask.toUInt();
-                    V3Number numval (itemp, iconstp->width());
+                    V3Number numval(itemp, iconstp->width());
                     numval.opBitsOne(iconstp->num());
-                    uint32_t val  = numval.toUInt();
-                    for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) {
+                    uint32_t val = numval.toUInt();
+                    for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) {
                         if ((i & mask) == val) {
                             if (!m_valueItem[i]) {
                                 m_valueItem[i] = itemp;
                             } else if (!itemp->ignoreOverlap() && !bitched) {
-                                icondp->v3warn(CASEOVERLAP, "Case values overlap (example pattern 0x"
-                                               <<std::hex<<i<<")");
+                                icondp->v3warn(CASEOVERLAP,
+                                               "Case values overlap (example pattern 0x"
+                                                   << std::hex << i << ")");
                                 bitched = true;
                                 m_caseNoOverlapsAllCovered = false;
                             }
@@ -192,15 +198,16 @@ private:
             }
             // Defaults were moved to last in the caseitem list by V3LinkDot
             if (itemp->isDefault()) {  // Case statement's default... Fill the table
-                for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) {
+                for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) {
                     if (!m_valueItem[i]) m_valueItem[i] = itemp;
                 }
             }
         }
-        for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) {
+        for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) {
             if (!m_valueItem[i]) {
-                nodep->v3warn(CASEINCOMPLETE, "Case values incompletely covered (example pattern 0x"
-                              <<std::hex<<i<<")");
+                nodep->v3warn(CASEINCOMPLETE, "Case values incompletely covered "
+                                              "(example pattern 0x"
+                                                  << std::hex << i << ")");
                 m_caseNoOverlapsAllCovered = false;
                 return false;
             }
@@ -213,24 +220,23 @@ private:
 
         // Convert valueItem from AstCaseItem* to the expression
         // Not done earlier, as we may now have a NULL because it's just a ";" NOP branch
-        for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) {
+        for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) {
             m_valueItem[i] = VN_CAST(m_valueItem[i], CaseItem)->bodysp();
         }
         return true;  // All is fine
     }
 
     AstNode* replaceCaseFastRecurse(AstNode* cexprp, int msb, uint32_t upperValue) {
-        if (msb<0) {
+        if (msb < 0) {
             // There's no space for a IF.  We know upperValue is thus down to a specific
             // exact value, so just return the tree value
             // Note can't clone here, as we're going to check for equivalence above
             return m_valueItem[upperValue];
-        }
-        else {
+        } else {
             // Make left and right subtrees
             // cexpr[msb:lsb] == 1
-            AstNode* tree0p = replaceCaseFastRecurse(cexprp, msb-1, upperValue | 0);
-            AstNode* tree1p = replaceCaseFastRecurse(cexprp, msb-1, upperValue | (1UL<<msb));
+            AstNode* tree0p = replaceCaseFastRecurse(cexprp, msb - 1, upperValue | 0);
+            AstNode* tree1p = replaceCaseFastRecurse(cexprp, msb - 1, upperValue | (1UL << msb));
 
             if (tree0p == tree1p) {
                 // Same logic on both sides, so we can just return one of 'em
@@ -238,11 +244,12 @@ private:
             }
             // We could have a "checkerboard" with A B A B, we can use the same IF on both edges
             bool same = true;
-            for (uint32_t a=upperValue,
-                     b=(upperValue|(1UL<<msb));
-                 a < (upperValue|(1UL<<msb));
-                 a++, b++) {
-                if (m_valueItem[a] != m_valueItem[b]) { same = false; break; }
+            for (uint32_t a = upperValue, b = (upperValue | (1UL << msb));
+                 a < (upperValue | (1UL << msb)); a++, b++) {
+                if (m_valueItem[a] != m_valueItem[b]) {
+                    same = false;
+                    break;
+                }
             }
             if (same) {
                 VL_DO_DANGLING(tree1p->deleteTree(), tree1p);
@@ -256,14 +263,12 @@ private:
             if (tree1p && !tree1p->user3()) tree1p = tree1p->cloneTree(true);
 
             // Alternate scheme if we ever do multiple bits at a time:
-            //V3Number nummask (cexprp, cexprp->width(), (1UL<<msb));
-            //AstNode* and1p = new AstAnd(cexprp->fileline(), cexprp->cloneTree(false),
+            // V3Number nummask (cexprp, cexprp->width(), (1UL<<msb));
+            // AstNode* and1p = new AstAnd(cexprp->fileline(), cexprp->cloneTree(false),
             //                            new AstConst(cexprp->fileline(), nummask));
-            AstNode* and1p = new AstSel(cexprp->fileline(), cexprp->cloneTree(false),
-                                        msb, 1);
-            AstNode* eqp = new AstNeq(cexprp->fileline(),
-                                      new AstConst(cexprp->fileline(), 0),
-                                      and1p);
+            AstNode* and1p = new AstSel(cexprp->fileline(), cexprp->cloneTree(false), msb, 1);
+            AstNode* eqp
+                = new AstNeq(cexprp->fileline(), new AstConst(cexprp->fileline(), 0), and1p);
             AstIf* ifp = new AstIf(cexprp->fileline(), eqp, tree1p, tree0p);
             ifp->user3(1);  // So we don't bother to clone it
             return ifp;
@@ -276,10 +281,10 @@ private:
         //                      IF(msb-1, 01, 00))
         AstNode* cexprp = nodep->exprp()->unlinkFrBack();
 
-        if (debug()>=9) {
-            for (uint32_t i=0; i<(1UL<<m_caseWidth); ++i) {
+        if (debug() >= 9) {
+            for (uint32_t i = 0; i < (1UL << m_caseWidth); ++i) {
                 if (AstNode* itemp = m_valueItem[i]) {
-                    UINFO(9,"Value "<<std::hex<<i<<" "<<itemp<<endl);
+                    UINFO(9, "Value " << std::hex << i << " " << itemp << endl);
                 }
             }
         }
@@ -288,15 +293,18 @@ private:
         replaceCaseParallel(nodep, m_caseNoOverlapsAllCovered);
 
         AstNode::user3ClearTree();
-        AstNode* ifrootp = replaceCaseFastRecurse(cexprp, m_caseWidth-1, 0UL);
+        AstNode* ifrootp = replaceCaseFastRecurse(cexprp, m_caseWidth - 1, 0UL);
         // Case expressions can't be linked twice, so clone them
         if (ifrootp && !ifrootp->user3()) ifrootp = ifrootp->cloneTree(true);
 
-        if (ifrootp) nodep->replaceWith(ifrootp);
-        else nodep->unlinkFrBack();
+        if (ifrootp) {
+            nodep->replaceWith(ifrootp);
+        } else {
+            nodep->unlinkFrBack();
+        }
         VL_DO_DANGLING(nodep->deleteTree(), nodep);
         VL_DO_DANGLING(cexprp->deleteTree(), cexprp);
-        if (debug()>=9) ifrootp->dumpTree(cout, "    _simp: ");
+        if (debug() >= 9) ifrootp->dumpTree(cout, "    _simp: ");
     }
 
     void replaceCaseComplicated(AstCase* nodep) {
@@ -307,9 +315,10 @@ private:
         AstNode* cexprp = nodep->exprp()->unlinkFrBack();
         // We'll do this in two stages.  First stage, convert the conditions to
         // the appropriate IF AND terms.
-        if (debug()>=9) nodep->dumpTree(cout, "    _comp_IN:   ");
+        if (debug() >= 9) nodep->dumpTree(cout, "    _comp_IN:   ");
         bool hadDefault = false;
-        for (AstCaseItem* itemp = nodep->itemsp(); itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
+        for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+             itemp = VN_CAST(itemp->nextp(), CaseItem)) {
             if (!itemp->condsp()) {
                 // Default clause.  Just make true, we'll optimize it away later
                 itemp->condsp(new AstConst(itemp->fileline(), AstConst::LogicTrue()));
@@ -318,7 +327,7 @@ private:
                 // Expressioned clause
                 AstNode* icondNextp = NULL;
                 AstNode* ifexprp = NULL;  // If expression to test
-                for (AstNode* icondp = itemp->condsp(); icondp!=NULL; icondp=icondNextp) {
+                for (AstNode* icondp = itemp->condsp(); icondp; icondp = icondNextp) {
                     icondNextp = icondp->nextp();
                     icondp->unlinkFrBack();
 
@@ -326,7 +335,8 @@ private:
                     AstConst* iconstp = VN_CAST(icondp, Const);
                     if (iconstp && neverItem(nodep, iconstp)) {
                         // X in casez can't ever be executed
-                        VL_DO_DANGLING(icondp->deleteTree(), icondp); VL_DANGLING(iconstp);
+                        VL_DO_DANGLING(icondp->deleteTree(), icondp);
+                        VL_DANGLING(iconstp);
                         // For simplicity, make expression that is not equal, and let later
                         // optimizations remove it
                         condp = new AstConst(itemp->fileline(), AstConst::LogicFalse());
@@ -336,16 +346,17 @@ private:
                                                           irangep->rhsp()->unlinkFrBack());
                     } else if (iconstp && iconstp->num().isFourState()
                                && (nodep->casex() || nodep->casez() || nodep->caseInside())) {
-                        V3Number nummask (itemp, iconstp->width());
+                        V3Number nummask(itemp, iconstp->width());
                         nummask.opBitsNonX(iconstp->num());
-                        V3Number numval  (itemp, iconstp->width());
+                        V3Number numval(itemp, iconstp->width());
                         numval.opBitsOne(iconstp->num());
                         AstNode* and1p = new AstAnd(itemp->fileline(), cexprp->cloneTree(false),
                                                     new AstConst(itemp->fileline(), nummask));
                         AstNode* and2p = new AstAnd(itemp->fileline(),
                                                     new AstConst(itemp->fileline(), numval),
                                                     new AstConst(itemp->fileline(), nummask));
-                        VL_DO_DANGLING(icondp->deleteTree(), icondp); VL_DANGLING(iconstp);
+                        VL_DO_DANGLING(icondp->deleteTree(), icondp);
+                        VL_DANGLING(iconstp);
                         condp = AstEq::newTyped(itemp->fileline(), and1p, and2p);
                     } else {
                         // Not a caseX mask, we can simply build CASEEQ(cexpr icond)
@@ -367,11 +378,10 @@ private:
         if (!hadDefault) {
             // If there was no default, add a empty one, this greatly simplifies below code
             // and constant propagation will just eliminate it for us later.
-            nodep->addItemsp(new AstCaseItem(nodep->fileline(),
-                                             new AstConst(nodep->fileline(), AstConst::LogicTrue()),
-                                             NULL));
+            nodep->addItemsp(new AstCaseItem(
+                nodep->fileline(), new AstConst(nodep->fileline(), AstConst::LogicTrue()), NULL));
         }
-        if (debug()>=9) nodep->dumpTree(cout, "    _comp_COND: ");
+        if (debug() >= 9) nodep->dumpTree(cout, "    _comp_COND: ");
         // Now build the IF statement tree
         // The tree can be quite huge.  Pull ever group of 8 out, and make a OR tree.
         // This reduces the depth for the bottom elements, at the cost of
@@ -382,46 +392,56 @@ private:
         AstNode* grouprootp = NULL;
         AstIf* groupnextp = NULL;
         AstIf* itemnextp = NULL;
-        for (AstCaseItem* itemp = nodep->itemsp(); itemp; itemp=VN_CAST(itemp->nextp(), CaseItem)) {
+        for (AstCaseItem* itemp = nodep->itemsp(); itemp;
+             itemp = VN_CAST(itemp->nextp(), CaseItem)) {
             AstNode* istmtsp = itemp->bodysp();  // Maybe null -- no action.
             if (istmtsp) istmtsp->unlinkFrBackWithNext();
             // Expressioned clause
             AstNode* ifexprp = itemp->condsp()->unlinkFrBack();
-            {   // Prepare for next group
+            {  // Prepare for next group
                 if (++depth > CASE_ENCODER_GROUP_DEPTH) depth = 1;
                 if (depth == 1) {  // First group or starting new group
                     itemnextp = NULL;
-                    AstIf* newp = new AstIf(itemp->fileline(),
-                                            ifexprp->cloneTree(true), NULL, NULL);
-                    if (groupnextp) groupnextp->addElsesp(newp);
-                    else grouprootp = newp;
+                    AstIf* newp
+                        = new AstIf(itemp->fileline(), ifexprp->cloneTree(true), NULL, NULL);
+                    if (groupnextp) {
+                        groupnextp->addElsesp(newp);
+                    } else {
+                        grouprootp = newp;
+                    }
                     groupnextp = newp;
                 } else {  // Continue group, modify if condition to OR in this new condition
                     AstNode* condp = groupnextp->condp()->unlinkFrBack();
-                    groupnextp->condp(new AstOr(ifexprp->fileline(),
-                                                condp,
-                                                ifexprp->cloneTree(true)));
+                    groupnextp->condp(
+                        new AstOr(ifexprp->fileline(), condp, ifexprp->cloneTree(true)));
                 }
             }
-            {   // Make the new lower IF and attach in the tree
-                AstNode* itemexprp = ifexprp; VL_DANGLING(ifexprp);
-                if (depth == (CASE_ENCODER_GROUP_DEPTH)) {  // End of group - can skip the condition
+            {  // Make the new lower IF and attach in the tree
+                AstNode* itemexprp = ifexprp;
+                VL_DANGLING(ifexprp);
+                if (depth == CASE_ENCODER_GROUP_DEPTH) {  // End of group - can skip the condition
                     VL_DO_DANGLING(itemexprp->deleteTree(), itemexprp);
                     itemexprp = new AstConst(itemp->fileline(), AstConst::LogicTrue());
                 }
                 AstIf* newp = new AstIf(itemp->fileline(), itemexprp, istmtsp, NULL);
-                if (itemnextp) itemnextp->addElsesp(newp);
-                else groupnextp->addIfsp(newp);  // First in a new group
+                if (itemnextp) {
+                    itemnextp->addElsesp(newp);
+                } else {
+                    groupnextp->addIfsp(newp);  // First in a new group
+                }
                 itemnextp = newp;
             }
         }
-        if (debug()>=9) nodep->dumpTree(cout, "    _comp_TREE: ");
+        if (debug() >= 9) nodep->dumpTree(cout, "    _comp_TREE: ");
         // Handle any assertions
         replaceCaseParallel(nodep, false);
         // Replace the CASE... with IF...
-        if (debug()>=9 && grouprootp) grouprootp->dumpTree(cout, "     _new: ");
-        if (grouprootp) nodep->replaceWith(grouprootp);
-        else nodep->unlinkFrBack();
+        if (debug() >= 9 && grouprootp) grouprootp->dumpTree(cout, "     _new: ");
+        if (grouprootp) {
+            nodep->replaceWith(grouprootp);
+        } else {
+            nodep->unlinkFrBack();
+        }
         VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
@@ -451,7 +471,7 @@ private:
     virtual void visit(AstCase* nodep) VL_OVERRIDE {
         V3Case::caseLint(nodep);
         iterateChildren(nodep);
-        if (debug()>=9) nodep->dumpTree(cout, " case_old: ");
+        if (debug() >= 9) nodep->dumpTree(cout, " case_old: ");
         if (isCaseTreeFast(nodep) && v3Global.opt.oCase()) {
             // It's a simple priority encoder or complete statement
             // we can make a tree of statements to avoid extra comparisons
@@ -471,9 +491,7 @@ public:
         m_caseWidth = 0;
         m_caseItems = 0;
         m_caseNoOverlapsAllCovered = false;
-        for (uint32_t i=0; i<(1UL<<CASE_OVERLAP_WIDTH); ++i) {
-            m_valueItem[i] = NULL;
-        }
+        for (uint32_t i = 0; i < (1UL << CASE_OVERLAP_WIDTH); ++i) m_valueItem[i] = NULL;
         iterate(nodep);
     }
     virtual ~CaseVisitor() {
@@ -486,13 +504,11 @@ public:
 // Case class functions
 
 void V3Case::caseAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        CaseVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { CaseVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("case", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
 void V3Case::caseLint(AstNodeCase* nodep) {
-    UINFO(4,__FUNCTION__<<": "<<endl);
-    CaseLintVisitor visitor (nodep);
+    UINFO(4, __FUNCTION__ << ": " << endl);
+    CaseLintVisitor visitor(nodep);
 }
