@@ -209,7 +209,7 @@ public:
         }
     }
 
-    void applyBlock(AstBegin* nodep) {
+    void applyBlock(AstNodeBlock* nodep) {
         AstPragmaType pragma = AstPragmaType::COVERAGE_BLOCK_OFF;
         if (!nodep->unnamed()) {
             for (StringSet::const_iterator it = m_coverageOffBlocks.begin();
@@ -250,7 +250,7 @@ public:
         return (m_on > rh.m_on);
     }
 };
-std::ostream& operator<<(std::ostream& os, V3ConfigIgnoresLine rhs) {
+std::ostream& operator<<(std::ostream& os, const V3ConfigIgnoresLine& rhs) {
     return os << rhs.m_lineno << ", " << rhs.m_code << ", " << rhs.m_on;
 }
 
@@ -267,7 +267,7 @@ class V3ConfigFile {
 
     LineAttrMap m_lineAttrs;  // Atributes to line mapping
     IgnLines m_ignLines;  // Ignore line settings
-    Waivers m_waivers; // Waive messages
+    Waivers m_waivers;  // Waive messages
 
     struct {
         int lineno;  // Last line number
@@ -311,7 +311,7 @@ public:
         m_waivers.push_back(make_pair(code, match));
     }
 
-    void applyBlock(AstBegin* nodep) {
+    void applyBlock(AstNodeBlock* nodep) {
         // Apply to block at this line
         AstPragmaType pragma = AstPragmaType::COVERAGE_BLOCK_OFF;
         if (lineMatch(nodep->fileline()->lineno(), pragma)) {
@@ -327,12 +327,12 @@ public:
     inline void applyIgnores(FileLine* filelinep) {
         // HOT routine, called each parsed token line of this filename
         if (m_lastIgnore.lineno != filelinep->lineno()) {
-            // UINFO(9,"   ApplyIgnores for "<<filelinep->ascii()<<endl);
+            // UINFO(9, "   ApplyIgnores for " << filelinep->ascii() << endl);
             // Process all on/offs for lines up to and including the current line
             int curlineno = filelinep->lastLineno();
             for (; m_lastIgnore.it != m_ignLines.end(); ++m_lastIgnore.it) {
                 if (m_lastIgnore.it->m_lineno > curlineno) break;
-                // UINFO(9,"     Hit "<<*m_lastIt<<endl);
+                // UINFO(9, "     Hit " << *m_lastIt << endl);
                 filelinep->warnOn(m_lastIgnore.it->m_code, m_lastIgnore.it->m_on);
             }
             if (0 && debug() >= 9) {
@@ -346,7 +346,9 @@ public:
     bool waive(V3ErrorCode code, const string& match) {
         for (Waivers::const_iterator it = m_waivers.begin(); it != m_waivers.end(); ++it) {
             if (((it->first == code) || (it->first == V3ErrorCode::I_LINT))
-                && VString::wildmatch(match, it->second)) return true;
+                && VString::wildmatch(match, it->second)) {
+                return true;
+            }
         }
         return false;
     }
@@ -454,8 +456,8 @@ void V3Config::addVarAttr(FileLine* fl, const string& module, const string& ftas
     }
 }
 
-void V3Config::addWaiver(V3ErrorCode code, const string& filename, const string& match) {
-    V3ConfigResolver::s().files().at(filename).addWaiver(code, match);
+void V3Config::addWaiver(V3ErrorCode code, const string& filename, const string& message) {
+    V3ConfigResolver::s().files().at(filename).addWaiver(code, message);
 }
 
 void V3Config::applyCase(AstCase* nodep) {
