@@ -63,9 +63,7 @@ private:
 
 public:
     // CONSTRUCTORS
-    explicit DeadModVisitor(AstNodeModule* nodep) {
-        iterate(nodep);
-    }
+    explicit DeadModVisitor(AstNodeModule* nodep) { iterate(nodep); }
     virtual ~DeadModVisitor() {}
 };
 
@@ -80,51 +78,46 @@ private:
     //  AstVar::user1()         -> int. Count of number of references
     //  AstVarScope::user1()    -> int. Count of number of references
     //  AstNodeDType::user1()   -> int. Count of number of references
-    AstUser1InUse       m_inuser1;
+    AstUser1InUse m_inuser1;
 
     // TYPES
-    typedef std::multimap<AstVarScope*,AstNodeAssign*> AssignMap;
+    typedef std::multimap<AstVarScope*, AstNodeAssign*> AssignMap;
 
     // STATE
-    AstNodeModule*              m_modp;         // Current module
-    std::vector<AstVar*>        m_varsp;        // List of all encountered to avoid another loop through tree
-    std::vector<AstNode*>       m_dtypesp;      // List of all encountered to avoid another loop through tree
-    std::vector<AstVarScope*>   m_vscsp;        // List of all encountered to avoid another loop through tree
-    std::vector<AstScope*>      m_scopesp;      // List of all encountered to avoid another loop through tree
-    std::vector<AstCell*>       m_cellsp;       // List of all encountered to avoid another loop through tree
-    AssignMap                   m_assignMap;    // List of all simple assignments for each variable
-    bool                        m_elimUserVars; // Allow removal of user's vars
-    bool                        m_elimDTypes;   // Allow removal of DTypes
-    bool                        m_elimScopes;   // Allow removal of Scopes
-    bool                        m_elimCells;    // Allow removal of Cells
-    bool                        m_sideEffect;   // Side effects discovered in assign RHS
+    AstNodeModule* m_modp;  // Current module
+    // List of all encountered to avoid another loop through tree
+    std::vector<AstVar*> m_varsp;
+    std::vector<AstNode*> m_dtypesp;
+    std::vector<AstVarScope*> m_vscsp;
+    std::vector<AstScope*> m_scopesp;
+    std::vector<AstCell*> m_cellsp;
+    std::vector<AstClass*> m_classesp;
+
+    AssignMap m_assignMap;  // List of all simple assignments for each variable
+    bool m_elimUserVars;  // Allow removal of user's vars
+    bool m_elimDTypes;  // Allow removal of DTypes
+    bool m_elimScopes;  // Allow removal of Scopes
+    bool m_elimCells;  // Allow removal of Cells
+    bool m_sideEffect;  // Side effects discovered in assign RHS
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     void checkAll(AstNode* nodep) {
         if (nodep != nodep->dtypep()) {  // NodeDTypes reference themselves
-            if (AstNode* subnodep = nodep->dtypep()) {
-                subnodep->user1Inc();
-            }
-        }
-        if (AstNode* subnodep = nodep->getChildDTypep()) {
-            subnodep->user1Inc();
+            if (AstNode* subnodep = nodep->dtypep()) subnodep->user1Inc();
         }
+        if (AstNode* subnodep = nodep->getChildDTypep()) subnodep->user1Inc();
     }
     void checkDType(AstNodeDType* nodep) {
         if (!nodep->generic()  // Don't remove generic types
             && m_elimDTypes  // dtypes stick around until post-widthing
             && !VN_IS(nodep, MemberDType)  // Keep member names iff upper type exists
-            ) {
+        ) {
             m_dtypesp.push_back(nodep);
         }
-        if (AstNode* subnodep = nodep->virtRefDTypep()) {
-            subnodep->user1Inc();
-        }
-        if (AstNode* subnodep = nodep->virtRefDType2p()) {
-            subnodep->user1Inc();
-        }
+        if (AstNode* subnodep = nodep->virtRefDTypep()) subnodep->user1Inc();
+        if (AstNode* subnodep = nodep->virtRefDType2p()) subnodep->user1Inc();
     }
 
     // VISITORS
@@ -135,6 +128,13 @@ private:
             if (!nodep->dead()) {
                 iterateChildren(nodep);
                 checkAll(nodep);
+                if (AstClass* classp = VN_CAST(nodep, Class)) {
+                    if (classp->extendsp()) classp->extendsp()->user1Inc();
+                    if (classp->packagep()) classp->packagep()->user1Inc();
+                    m_classesp.push_back(classp);
+                    // TODO we don't reclaim dead classes yet - graph implementation instead?
+                    classp->user1Inc();
+                }
             }
         }
         m_modp = origModp;
@@ -148,7 +148,9 @@ private:
         iterateChildren(nodep);
         checkAll(nodep);
         if (nodep->aboveScopep()) nodep->aboveScopep()->user1Inc();
-
+        // Class packages might have no children, but need to remain as
+        // long as the class they refer to is needed
+        if (VN_IS(m_modp, Class) || VN_IS(m_modp, ClassPackage)) nodep->user1Inc();
         if (!nodep->isTop() && !nodep->varsp() && !nodep->blocksp() && !nodep->finalClksp()) {
             m_scopesp.push_back(nodep);
         }
@@ -167,20 +169,24 @@ private:
             nodep->varScopep()->user1Inc();
             nodep->varScopep()->varp()->user1Inc();
         }
-        if (nodep->varp()) {
-            nodep->varp()->user1Inc();
-        }
+        if (nodep->varp()) nodep->varp()->user1Inc();
         if (nodep->packagep()) {
-            if (m_elimCells) nodep->packagep(NULL);
-            else nodep->packagep()->user1Inc();
+            if (m_elimCells) {
+                nodep->packagep(NULL);
+            } else {
+                nodep->packagep()->user1Inc();
+            }
         }
     }
     virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         checkAll(nodep);
         if (nodep->packagep()) {
-            if (m_elimCells) nodep->packagep(NULL);
-            else nodep->packagep()->user1Inc();
+            if (m_elimCells) {
+                nodep->packagep(NULL);
+            } else {
+                nodep->packagep()->user1Inc();
+            }
         }
     }
     virtual void visit(AstMethodCall* nodep) VL_OVERRIDE {
@@ -192,10 +198,26 @@ private:
         checkDType(nodep);
         checkAll(nodep);
         if (nodep->packagep()) {
-            if (m_elimCells) nodep->packagep(NULL);
-            else nodep->packagep()->user1Inc();
+            if (m_elimCells) {
+                nodep->packagep(NULL);
+            } else {
+                nodep->packagep()->user1Inc();
+            }
         }
     }
+    virtual void visit(AstClassRefDType* nodep) VL_OVERRIDE {
+        iterateChildren(nodep);
+        checkDType(nodep);
+        checkAll(nodep);
+        if (nodep->packagep()) {
+            if (m_elimCells) {
+                nodep->packagep(NULL);
+            } else {
+                nodep->packagep()->user1Inc();
+            }
+        }
+        if (nodep->classp()) nodep->classp()->user1Inc();
+    }
     virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         checkDType(nodep);
@@ -205,8 +227,11 @@ private:
         iterateChildren(nodep);
         checkAll(nodep);
         if (nodep->packagep()) {
-            if (m_elimCells) nodep->packagep(NULL);
-            else nodep->packagep()->user1Inc();
+            if (m_elimCells) {
+                nodep->packagep(NULL);
+            } else {
+                nodep->packagep()->user1Inc();
+            }
         }
         checkAll(nodep);
     }
@@ -241,17 +266,13 @@ private:
         iterateChildren(nodep);
         checkAll(nodep);
         if (nodep->scopep()) nodep->scopep()->user1Inc();
-        if (mightElimVar(nodep->varp())) {
-            m_vscsp.push_back(nodep);
-        }
+        if (mightElimVar(nodep->varp())) m_vscsp.push_back(nodep);
     }
     virtual void visit(AstVar* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         checkAll(nodep);
         if (nodep->isSigPublic() && m_modp && VN_IS(m_modp, Package)) m_modp->user1Inc();
-        if (mightElimVar(nodep)) {
-            m_varsp.push_back(nodep);
-        }
+        if (mightElimVar(nodep)) m_varsp.push_back(nodep);
     }
     virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         // See if simple assignments to variables may be eliminated because
@@ -284,14 +305,15 @@ private:
         // Kill any unused modules
         // V3LinkCells has a graph that is capable of this too, but we need to do it
         // after we've done all the generate blocks
-        for (bool retry=true; retry; ) {
+        for (bool retry = true; retry;) {
             retry = false;
             AstNodeModule* nextmodp;
-            for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp; modp=nextmodp) {
+            for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp; modp = nextmodp) {
                 nextmodp = VN_CAST(modp->nextp(), NodeModule);
-                if (modp->dead() || (modp->level()>2 && modp->user1()==0 && !modp->internal())) {
+                if (modp->dead()
+                    || (modp->level() > 2 && modp->user1() == 0 && !modp->internal())) {
                     // > 2 because L1 is the wrapper, L2 is the top user module
-                    UINFO(4,"  Dead module "<<modp<<endl);
+                    UINFO(4, "  Dead module " << modp << endl);
                     // And its children may now be killable too; correct counts
                     // Recurse, as cells may not be directly under the module but in a generate
                     if (!modp->dead()) {  // If was dead didn't increment user1's
@@ -305,26 +327,23 @@ private:
     }
     bool mightElimVar(AstVar* nodep) {
         return (!nodep->isSigPublic()  // Can't elim publics!
-                && !nodep->isIO()
+                && !nodep->isIO() && !nodep->isClassMember()
                 && ((nodep->isTemp() && !nodep->isTrace())
                     || (nodep->isParam() && !nodep->isTrace() && !v3Global.opt.xmlOnly())
                     || m_elimUserVars));  // Post-Trace can kill most anything
     }
 
     void deadCheckScope() {
-        for (bool retry=true; retry; ) {
+        for (bool retry = true; retry;) {
             retry = false;
-            for (std::vector<AstScope*>::iterator it = m_scopesp.begin();
-                 it != m_scopesp.end();++it) {
+            for (std::vector<AstScope*>::iterator it = m_scopesp.begin(); it != m_scopesp.end();
+                 ++it) {
                 AstScope* scp = *it;
-                if (!scp)
-                    continue;
+                if (!scp) continue;
                 if (scp->user1() == 0) {
                     UINFO(4, "  Dead AstScope " << scp << endl);
                     scp->aboveScopep()->user1Inc(-1);
-                    if (scp->dtypep()) {
-                        scp->dtypep()->user1Inc(-1);
-                    }
+                    if (scp->dtypep()) scp->dtypep()->user1Inc(-1);
                     VL_DO_DANGLING(scp->unlinkFrBack()->deleteTree(), scp);
                     *it = NULL;
                     retry = true;
@@ -334,7 +353,7 @@ private:
     }
 
     void deadCheckCells() {
-        for (std::vector<AstCell*>::iterator it = m_cellsp.begin(); it!=m_cellsp.end(); ++it) {
+        for (std::vector<AstCell*>::iterator it = m_cellsp.begin(); it != m_cellsp.end(); ++it) {
             AstCell* cellp = *it;
             if (cellp->user1() == 0 && !cellp->modp()->stmtsp()) {
                 cellp->modp()->user1Inc(-1);
@@ -342,18 +361,35 @@ private:
             }
         }
     }
+    void deadCheckClasses() {
+        for (bool retry = true; retry;) {
+            retry = false;
+            for (std::vector<AstClass*>::iterator it = m_classesp.begin(); it != m_classesp.end();
+                 ++it) {
+                if (AstClass* nodep = *it) {  // NULL if deleted earlier
+                    if (nodep->user1() == 0) {
+                        if (nodep->extendsp()) nodep->extendsp()->user1Inc(-1);
+                        if (nodep->packagep()) nodep->packagep()->user1Inc(-1);
+                        VL_DO_DANGLING(pushDeletep(nodep->unlinkFrBack()), nodep);
+                        *it = NULL;
+                        retry = true;
+                    }
+                }
+            }
+        }
+    }
 
     void deadCheckVar() {
         // Delete any unused varscopes
-        for (std::vector<AstVarScope*>::iterator it = m_vscsp.begin(); it!=m_vscsp.end(); ++it) {
+        for (std::vector<AstVarScope*>::iterator it = m_vscsp.begin(); it != m_vscsp.end(); ++it) {
             AstVarScope* vscp = *it;
             if (vscp->user1() == 0) {
-                UINFO(4,"  Dead "<<vscp<<endl);
-                std::pair<AssignMap::iterator,AssignMap::iterator> eqrange
+                UINFO(4, "  Dead " << vscp << endl);
+                std::pair<AssignMap::iterator, AssignMap::iterator> eqrange
                     = m_assignMap.equal_range(vscp);
                 for (AssignMap::iterator itr = eqrange.first; itr != eqrange.second; ++itr) {
                     AstNodeAssign* assp = itr->second;
-                    UINFO(4,"    Dead assign "<<assp<<endl);
+                    UINFO(4, "    Dead assign " << assp << endl);
                     assp->dtypep()->user1Inc(-1);
                     VL_DO_DANGLING(assp->unlinkFrBack()->deleteTree(), assp);
                 }
@@ -362,40 +398,36 @@ private:
                 VL_DO_DANGLING(vscp->unlinkFrBack()->deleteTree(), vscp);
             }
         }
-        for (bool retry=true; retry; ) {
+        for (bool retry = true; retry;) {
             retry = false;
-            for (std::vector<AstVar *>::iterator it = m_varsp.begin(); it != m_varsp.end();++it) {
+            for (std::vector<AstVar*>::iterator it = m_varsp.begin(); it != m_varsp.end(); ++it) {
                 AstVar* varp = *it;
-                if (!varp)
-                    continue;
+                if (!varp) continue;
                 if (varp->user1() == 0) {
                     UINFO(4, "  Dead " << varp << endl);
-                    if (varp->dtypep()) {
-                        varp->dtypep()->user1Inc(-1);
-                    }
+                    if (varp->dtypep()) varp->dtypep()->user1Inc(-1);
                     VL_DO_DANGLING(varp->unlinkFrBack()->deleteTree(), varp);
                     *it = NULL;
                     retry = true;
                 }
             }
         }
-        for (std::vector<AstNode*>::iterator it = m_dtypesp.begin(); it != m_dtypesp.end();++it) {
+        for (std::vector<AstNode*>::iterator it = m_dtypesp.begin(); it != m_dtypesp.end(); ++it) {
             if ((*it)->user1() == 0) {
-                AstNodeUOrStructDType *classp;
+                AstNodeUOrStructDType* classp;
                 // It's possible that there if a reference to each individual member, but
                 // not to the dtype itself.  Check and don't remove the parent dtype if
                 // members are still alive.
                 if ((classp = VN_CAST((*it), NodeUOrStructDType))) {
                     bool cont = true;
-                    for (AstMemberDType *memberp = classp->membersp();
-                         memberp; memberp = VN_CAST(memberp->nextp(), MemberDType)) {
+                    for (AstMemberDType* memberp = classp->membersp(); memberp;
+                         memberp = VN_CAST(memberp->nextp(), MemberDType)) {
                         if (memberp->user1() != 0) {
                             cont = false;
                             break;
                         }
                     }
-                    if (!cont)
-                        continue;
+                    if (!cont) continue;
                 }
                 VL_DO_DANGLING((*it)->unlinkFrBack()->deleteTree(), *it);
             }
@@ -404,8 +436,8 @@ private:
 
 public:
     // CONSTRUCTORS
-    DeadVisitor(AstNetlist* nodep, bool elimUserVars, bool elimDTypes,
-                bool elimScopes, bool elimCells) {
+    DeadVisitor(AstNetlist* nodep, bool elimUserVars, bool elimDTypes, bool elimScopes,
+                bool elimCells) {
         m_modp = NULL;
         m_elimCells = elimCells;
         m_elimUserVars = elimUserVars;
@@ -422,6 +454,7 @@ public:
         // Otherwise we have no easy way to know if a scope is used
         if (elimScopes) deadCheckScope();
         if (elimCells) deadCheckCells();
+        deadCheckClasses();
         // Modules after vars, because might be vars we delete inside a mod we delete
         deadCheckMod();
 
@@ -435,41 +468,32 @@ public:
 // Dead class functions
 
 void V3Dead::deadifyModules(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DeadVisitor visitor (nodep, false, false, false, false);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DeadVisitor visitor(nodep, false, false, false, false); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("deadModules", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 6);
 }
 
 void V3Dead::deadifyDTypes(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DeadVisitor visitor (nodep, false, true, false, false);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DeadVisitor visitor(nodep, false, true, false, false); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("deadDtypes", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
 
 void V3Dead::deadifyDTypesScoped(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DeadVisitor visitor (nodep, false, true, true, false);
-    }  // Destruct before checking
-    V3Global::dumpCheckGlobalTree("deadDtypesScoped", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DeadVisitor visitor(nodep, false, true, true, false); }  // Destruct before checking
+    V3Global::dumpCheckGlobalTree("deadDtypesScoped", 0,
+                                  v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
 
 void V3Dead::deadifyAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DeadVisitor visitor (nodep, true, true, false, true);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DeadVisitor visitor(nodep, true, true, false, true); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("deadAll", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
 
 void V3Dead::deadifyAllScoped(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        DeadVisitor visitor (nodep, true, true, true, true);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { DeadVisitor visitor(nodep, true, true, true, true); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("deadAllScoped", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
