@@ -28,10 +28,9 @@
 class V3EmitV {
 public:
     static void emitv();
-    static void verilogForTree(AstNode* nodep, std::ostream& os=std::cout);
-    static void verilogPrefixedTree(AstNode* nodep, std::ostream& os,
-                                    const string& prefix, int flWidth,
-                                    AstSenTree* domainp, bool user3mark);
+    static void verilogForTree(AstNode* nodep, std::ostream& os = std::cout);
+    static void verilogPrefixedTree(AstNode* nodep, std::ostream& os, const string& prefix,
+                                    int flWidth, AstSenTree* domainp, bool user3mark);
     static void emitvFiles();
 };
 
