@@ -39,22 +39,27 @@ class FileLine;
 //! source file (each with its own unique filename number).
 class FileLineSingleton {
     // TYPES
-    typedef std::map<string,int> FileNameNumMap;
-    typedef std::map<string,V3LangCode> FileLangNumMap;
+    typedef std::map<string, int> FileNameNumMap;
+    typedef std::map<string, V3LangCode> FileLangNumMap;
     // MEMBERS
-    FileNameNumMap      m_namemap;      // filenameno for each filename
-    std::deque<string>  m_names;        // filename text for each filenameno
+    FileNameNumMap m_namemap;  // filenameno for each filename
+    std::deque<string> m_names;  // filename text for each filenameno
     std::deque<V3LangCode> m_languages;  // language for each filenameno
     // CONSTRUCTORS
-    FileLineSingleton() { }
-    ~FileLineSingleton() { }
+    FileLineSingleton() {}
+    ~FileLineSingleton() {}
+
 protected:
     friend class FileLine;
     int nameToNumber(const string& filename);
     const string numberToName(int filenameno) const { return m_names[filenameno]; }
     const V3LangCode numberToLang(int filenameno) const { return m_languages[filenameno]; }
     void numberToLang(int filenameno, const V3LangCode& l) { m_languages[filenameno] = l; }
-    void clear() { m_namemap.clear(); m_names.clear(); m_languages.clear(); }
+    void clear() {
+        m_namemap.clear();
+        m_names.clear();
+        m_languages.clear();
+    }
     void fileNameNumMapDumpXml(std::ostream& os);
     static const string filenameLetters(int fileno);
 };
@@ -65,12 +70,15 @@ class VFileContent {
     int m_id;  // Content ID number
     std::deque<string> m_lines;  // Source text lines
 public:
-    VFileContent() { static int s_id = 0; m_id = ++s_id; }
-    ~VFileContent() { }
+    VFileContent() {
+        static int s_id = 0;
+        m_id = ++s_id;
+    }
+    ~VFileContent() {}
     // METHODS
     void pushText(const string& text);  // Add arbitrary text (need not be line-by-line)
     string getLine(int lineno) const;
-    string ascii() const { return "ct"+cvtToStr(m_id); }
+    string ascii() const { return "ct" + cvtToStr(m_id); }
     static int debug();
 };
 std::ostream& operator<<(std::ostream& os, VFileContent* contentp);
@@ -104,6 +112,7 @@ protected:
     friend class V3PreLex;
     friend class V3PreProcImp;
     friend class V3PreShellImp;
+
 private:
     // CONSTRUCTORS
     static FileLineSingleton& singleton() {
@@ -114,49 +123,59 @@ private:
         static FileLine* defFilelinep = new FileLine(FileLine::EmptySecret());
         return *defFilelinep;
     }
+
 public:
-    explicit FileLine(const string& filename) {
-        m_lastLineno = m_firstLineno = 0;
-        m_lastColumn = m_firstColumn = 0;
-        m_filenameno = singleton().nameToNumber(filename);
-        m_contentLineno = 0;
-        m_contentp = NULL;
-        m_parent = NULL;
-        m_warnOn = defaultFileLine().m_warnOn;
-    }
-    explicit FileLine(FileLine* fromp) {
-        m_firstLineno = fromp->m_firstLineno;
-        m_firstColumn = fromp->m_firstColumn;
-        m_lastLineno = fromp->m_lastLineno;
-        m_lastColumn = fromp->m_lastColumn;
-        m_filenameno = fromp->m_filenameno;
-        m_contentLineno = fromp->m_contentLineno;
-        m_contentp = fromp->m_contentp;
-        m_parent = fromp->m_parent;
-        m_warnOn = fromp->m_warnOn;
-    }
+    explicit FileLine(const string& filename)
+        : m_firstLineno(0)
+        , m_firstColumn(0)
+        , m_lastLineno(0)
+        , m_lastColumn(0)
+        , m_filenameno(singleton().nameToNumber(filename))
+        , m_contentLineno(0)
+        , m_contentp(NULL)
+        , m_parent(NULL)
+        , m_warnOn(defaultFileLine().m_warnOn) {}
+    explicit FileLine(FileLine* fromp)
+        : m_firstLineno(fromp->m_firstLineno)
+        , m_firstColumn(fromp->m_firstColumn)
+        , m_lastLineno(fromp->m_lastLineno)
+        , m_lastColumn(fromp->m_lastColumn)
+        , m_filenameno(fromp->m_filenameno)
+        , m_contentLineno(fromp->m_contentLineno)
+        , m_contentp(fromp->m_contentp)
+        , m_parent(fromp->m_parent)
+        , m_warnOn(fromp->m_warnOn) {}
     struct EmptySecret {};  // Constructor selection
     explicit FileLine(EmptySecret);
     FileLine* copyOrSameFileLine();
     static void deleteAllRemaining();
-    ~FileLine() { }
+    ~FileLine() {}
 #ifdef VL_LEAK_CHECKS
     static void* operator new(size_t size);
     static void operator delete(void* obj, size_t size);
 #endif
-    void newContent() { m_contentp = new VFileContent; m_contentLineno = 1; }
     // METHODS
-    void lineno(int num) { m_firstLineno = num; m_lastLineno = num;
-        m_firstColumn = m_lastColumn = 1; }
+    void newContent();
+    void lineno(int num) {
+        m_firstLineno = num;
+        m_lastLineno = num;
+        m_firstColumn = m_lastColumn = 1;
+    }
     void language(V3LangCode lang) { singleton().numberToLang(m_filenameno, lang); }
     void filename(const string& name) { m_filenameno = singleton().nameToNumber(name); }
     void parent(FileLine* fileline) { m_parent = fileline; }
     void lineDirective(const char* textp, int& enterExitRef);
-    void linenoInc() { m_lastLineno++; m_lastColumn = 1; m_contentLineno++; }
-    void startToken() { m_firstLineno = m_lastLineno;
-        m_firstColumn = m_lastColumn; }
+    void linenoInc() {
+        m_lastLineno++;
+        m_lastColumn = 1;
+        m_contentLineno++;
+    }
+    void startToken() {
+        m_firstLineno = m_lastLineno;
+        m_firstColumn = m_lastColumn;
+    }
     // Advance last line/column based on given text
-    void forwardToken(const char* textp, size_t size, bool trackLines=true);
+    void forwardToken(const char* textp, size_t size, bool trackLines = true);
     int firstLineno() const { return m_firstLineno; }
     int firstColumn() const { return m_firstColumn; }
     int lastLineno() const { return m_lastLineno; }
@@ -172,13 +191,16 @@ public:
     string ascii() const;
     string asciiLineCol() const;
     const string filename() const { return singleton().numberToName(m_filenameno); }
-    bool filenameIsGlobal() const { return (filename() == commandLineFilename()
-                                            || filename() == builtInFilename()); }
+    bool filenameIsGlobal() const {
+        return (filename() == commandLineFilename() || filename() == builtInFilename());
+    }
     const string filenameLetters() const { return singleton().filenameLetters(m_filenameno); }
     const string filebasename() const;
     const string filebasenameNoExt() const;
     const string profileFuncname() const;
-    const string xml() const { return "fl=\""+filenameLetters()+cvtToStr(lastLineno())+"\""; }
+    const string xml() const {
+        return "fl=\"" + filenameLetters() + cvtToStr(lastLineno()) + "\"";
+    }
     const string xmlDetailedLocation() const;
     string lineDirectiveStrg(int enterExit) const;
 
@@ -202,16 +224,15 @@ public:
     // <command-line> and <built-in> match what GCC outputs
     static string commandLineFilename() { return "<command-line>"; }
     static string builtInFilename() { return "<built-in>"; }
-    static void globalWarnLintOff(bool flag) {
-        defaultFileLine().warnLintOff(flag); }
-    static void globalWarnStyleOff(bool flag) {
-        defaultFileLine().warnStyleOff(flag); }
+    static void globalWarnLintOff(bool flag) { defaultFileLine().warnLintOff(flag); }
+    static void globalWarnStyleOff(bool flag) { defaultFileLine().warnStyleOff(flag); }
     static void globalWarnOff(V3ErrorCode code, bool flag) {
-        defaultFileLine().warnOff(code, flag); }
+        defaultFileLine().warnOff(code, flag);
+    }
     static bool globalWarnOff(const string& code, bool flag) {
-        return defaultFileLine().warnOff(code, flag); }
-    static void fileNameNumMapDumpXml(std::ostream& os) {
-        singleton().fileNameNumMapDumpXml(os); }
+        return defaultFileLine().warnOff(code, flag);
+    }
+    static void fileNameNumMapDumpXml(std::ostream& os) { singleton().fileNameNumMapDumpXml(os); }
 
     // METHODS - Called from netlist
     // Merge warning disables from another fileline
@@ -237,13 +258,11 @@ public:
     /// Simplified information vs warnContextPrimary() to make dump clearer
     string warnContextSecondary() const { return warnContext(true); }
     bool operator==(const FileLine& rhs) const {
-        return (m_firstLineno == rhs.m_firstLineno
-                && m_firstColumn == rhs.m_firstColumn
-                && m_lastLineno == rhs.m_lastLineno
-                && m_lastColumn == rhs.m_lastColumn
-                && m_filenameno == rhs.m_filenameno
-                && m_warnOn == rhs.m_warnOn);
+        return (m_firstLineno == rhs.m_firstLineno && m_firstColumn == rhs.m_firstColumn
+                && m_lastLineno == rhs.m_lastLineno && m_lastColumn == rhs.m_lastColumn
+                && m_filenameno == rhs.m_filenameno && m_warnOn == rhs.m_warnOn);
     }
+
 private:
     void v3errorEndFatalGuts(std::ostringstream& str);
     string warnContext(bool secondary) const;
@@ -251,7 +270,9 @@ private:
 std::ostream& operator<<(std::ostream& os, FileLine* fileline);
 
 inline void FileLine::v3errorEndFatal(std::ostringstream& str) {
-    v3errorEnd(str); assert(0); VL_UNREACHABLE
+    v3errorEnd(str);
+    assert(0);
+    VL_UNREACHABLE
 }
 
 #endif  // Guard
