@@ -45,13 +45,13 @@ private:
     // Cleared on top scope
     //  AstVarScope::user2()    -> AstVarScope*.  Signal replacing activation with
     //  AstVarRef::user3()      -> bool.  Signal is replaced activation (already done)
-    AstUser2InUse       m_inuser2;
-    AstUser3InUse       m_inuser3;
+    AstUser2InUse m_inuser2;
+    AstUser3InUse m_inuser3;
 
     // STATE
-    AstActive*          m_activep;      // Inside activate statement
-    AstNodeModule*      m_topModp;      // Top module
-    AstScope*           m_scopetopp;    // Scope under TOPSCOPE
+    AstActive* m_activep;  // Inside activate statement
+    AstNodeModule* m_topModp;  // Top module
+    AstScope* m_scopetopp;  // Scope under TOPSCOPE
 
     // METHODS
     AstVarScope* genInpClk(AstVarScope* vscp) {
@@ -59,18 +59,19 @@ private:
             return VN_CAST(vscp->user2p(), VarScope);
         } else {
             AstVar* varp = vscp->varp();
-            string newvarname = "__VinpClk__"+vscp->scopep()->nameDotless()+"__"+varp->name();
+            string newvarname
+                = "__VinpClk__" + vscp->scopep()->nameDotless() + "__" + varp->name();
             // Create:  VARREF(inpclk)
             //          ...
             //          ASSIGN(VARREF(inpclk), VARREF(var))
-            AstVar* newvarp = new AstVar(varp->fileline(),
-                                         AstVarType::MODULETEMP, newvarname, varp);
+            AstVar* newvarp
+                = new AstVar(varp->fileline(), AstVarType::MODULETEMP, newvarname, varp);
             m_topModp->addStmtp(newvarp);
             AstVarScope* newvscp = new AstVarScope(vscp->fileline(), m_scopetopp, newvarp);
             m_scopetopp->addVarp(newvscp);
-            AstAssign* asninitp = new AstAssign(vscp->fileline(),
-                                                new AstVarRef(vscp->fileline(), newvscp, true),
-                                                new AstVarRef(vscp->fileline(), vscp, false));
+            AstAssign* asninitp
+                = new AstAssign(vscp->fileline(), new AstVarRef(vscp->fileline(), newvscp, true),
+                                new AstVarRef(vscp->fileline(), vscp, false));
             m_scopetopp->addFinalClkp(asninitp);
             //
             vscp->user2p(newvscp);
@@ -96,7 +97,7 @@ private:
         if (m_activep && !nodep->user3()) {
             nodep->user3(true);
             if (vscp->isCircular()) {
-                UINFO(8,"  VarActReplace "<<nodep<<endl);
+                UINFO(8, "  VarActReplace " << nodep << endl);
                 // Replace with the new variable
                 AstVarScope* newvscp = genInpClk(vscp);
                 AstVarRef* newrefp = new AstVarRef(nodep->fileline(), newvscp, nodep->lvalue());
@@ -112,9 +113,7 @@ private:
         m_activep = NULL;
         iterateChildren(nodep);
     }
-    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
     //-----
     virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
@@ -138,13 +137,13 @@ private:
     // NODE STATE
     // Cleared on top scope
     //  AstVarScope::user()     -> bool.  Set when the var has been used as clock
-    AstUser1InUse       m_inuser1;
+    AstUser1InUse m_inuser1;
 
     // STATE
-    AstActive* m_activep;       // Inside activate statement
-    bool m_tracingCall;         // Iterating into a call to a cfunc
-    AstNodeAssign* m_assignp;   // Inside assigndly statement
-    AstNodeModule* m_topModp;   // Top module
+    AstActive* m_activep;  // Inside activate statement
+    bool m_tracingCall;  // Iterating into a call to a cfunc
+    AstNodeAssign* m_assignp;  // Inside assigndly statement
+    AstNodeModule* m_topModp;  // Top module
 
     // VISITORS
     virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
@@ -153,7 +152,7 @@ private:
         {
             // Make the new clock signals and replace any activate references
             // See rename, it does some AstNode::userClearTree()'s
-            GenClkRenameVisitor visitor (nodep, m_topModp);
+            GenClkRenameVisitor visitor(nodep, m_topModp);
         }
     }
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
@@ -188,24 +187,24 @@ private:
         AstVarScope* vscp = nodep->varScopep();
         UASSERT_OBJ(vscp, nodep, "Scope not assigned");
         if (m_activep) {
-            UINFO(8,"  VarAct "<<nodep<<endl);
+            UINFO(8, "  VarAct " << nodep << endl);
             vscp->user1(true);
         }
         if (m_assignp && nodep->lvalue() && vscp->user1()) {
             // Variable was previously used as a clock, and is now being set
             // Thus a unordered generated clock...
-            UINFO(8,"  VarSetAct "<<nodep<<endl);
+            UINFO(8, "  VarSetAct " << nodep << endl);
             vscp->circular(true);
         }
     }
     virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
-        //UINFO(8,"ASS "<<nodep<<endl);
+        // UINFO(8, "ASS " << nodep << endl);
         m_assignp = nodep;
         iterateChildren(nodep);
         m_assignp = NULL;
     }
     virtual void visit(AstActive* nodep) VL_OVERRIDE {
-        UINFO(8,"ACTIVE "<<nodep<<endl);
+        UINFO(8, "ACTIVE " << nodep << endl);
         m_activep = nodep;
         UASSERT_OBJ(nodep->sensesp(), nodep, "Unlinked");
         iterateChildren(nodep->sensesp());  // iterateAndNext?
@@ -233,9 +232,7 @@ public:
 // GenClk class functions
 
 void V3GenClk::genClkAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        GenClkReadVisitor visitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { GenClkReadVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("genclk", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
