@@ -43,11 +43,11 @@ private:
     // NODE STATE
     // Entire netlist:
     //  AstNodeStmt::user4()    -> V3Hash.  Hash value of this node (hash of 0 is illegal)
-    //AstUser4InUse     in V3Hashed.h
+    // AstUser4InUse     in V3Hashed.h
 
     // STATE
-    V3Hash              m_lowerHash;    // Hash of the statement we're building
-    bool                m_cacheInUser4; // Use user4 to cache each V3Hash?
+    V3Hash m_lowerHash;  // Hash of the statement we're building
+    bool m_cacheInUser4;  // Use user4 to cache each V3Hash?
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -55,10 +55,12 @@ private:
     void nodeHashIterate(AstNode* nodep) {
         V3Hash thisHash;
         if (!m_cacheInUser4 || !nodep->user4()) {
-            UASSERT_OBJ(!(VN_IS(nodep->backp(), CFunc)
-                          && !(VN_IS(nodep, NodeStmt) || VN_IS(nodep, CFunc))), nodep,
-                        "Node "<<nodep->prettyTypeName()
-                        <<" in statement position but not marked stmt (node under function)");
+            UASSERT_OBJ(
+                !(VN_IS(nodep->backp(), CFunc)
+                  && !(VN_IS(nodep, NodeStmt) || VN_IS(nodep, CFunc))),
+                nodep,
+                "Node " << nodep->prettyTypeName()
+                        << " in statement position but not marked stmt (node under function)");
             V3Hash oldHash = m_lowerHash;
             {
                 m_lowerHash = nodep->sameHash();
@@ -66,20 +68,19 @@ private:
                             "sameHash function undefined (returns 0) for node under CFunc.");
                 // For identical nodes, the type should be the same thus
                 // dtypep should be the same too
-                m_lowerHash = V3Hash(m_lowerHash, V3Hash(nodep->type()<<6,
-                                                         V3Hash(nodep->dtypep())));
+                m_lowerHash
+                    = V3Hash(m_lowerHash, V3Hash(nodep->type() << 6, V3Hash(nodep->dtypep())));
                 // Now update m_lowerHash for our children's (and next children) contributions
                 iterateChildren(nodep);
                 // Store the hash value
                 nodep->user4(m_lowerHash.fullValue());
-                //UINFO(9, "    hashnode "<<m_lowerHash<<"  "<<nodep<<endl);
+                // UINFO(9, "    hashnode "<<m_lowerHash<<"  "<<nodep<<endl);
             }
             thisHash = m_lowerHash;
             m_lowerHash = oldHash;
         }
         // Update what will become the above node's hash
-        m_lowerHash += m_cacheInUser4
-            ? V3Hashed::nodeHash(nodep) : thisHash;
+        m_lowerHash += m_cacheInUser4 ? V3Hashed::nodeHash(nodep) : thisHash;
     }
 
     //--------------------
@@ -120,10 +121,8 @@ V3Hashed::iterator V3Hashed::hashAndInsert(AstNode* nodep) {
 }
 
 void V3Hashed::hash(AstNode* nodep) {
-    UINFO(8,"   hashI "<<nodep<<endl);
-    if (!nodep->user4p()) {
-        HashedVisitor visitor (nodep);
-    }
+    UINFO(8, "   hashI " << nodep << endl);
+    if (!nodep->user4p()) { HashedVisitor visitor(nodep); }
 }
 
 bool V3Hashed::sameNodes(AstNode* node1p, AstNode* node2p) {
@@ -135,7 +134,7 @@ bool V3Hashed::sameNodes(AstNode* node1p, AstNode* node2p) {
 
 void V3Hashed::erase(iterator it) {
     AstNode* nodep = iteratorNodep(it);
-    UINFO(8,"   erase "<<nodep<<endl);
+    UINFO(8, "   erase " << nodep << endl);
     UASSERT_OBJ(nodep->user4p(), nodep, "Called removeNode on non-hashed node");
     m_hashMmap.erase(it);
     nodep->user4p(NULL);  // So we don't allow removeNode again
@@ -149,24 +148,22 @@ void V3Hashed::check() {
 }
 
 void V3Hashed::dumpFilePrefixed(const string& nameComment, bool tree) {
-    if (v3Global.opt.dumpTree()) {
-        dumpFile(v3Global.debugFilename(nameComment)+".hash", tree);
-    }
+    if (v3Global.opt.dumpTree()) dumpFile(v3Global.debugFilename(nameComment) + ".hash", tree);
 }
 
 void V3Hashed::dumpFile(const string& filename, bool tree) {
-    const vl_unique_ptr<std::ofstream> logp (V3File::new_ofstream(filename));
-    if (logp->fail()) v3fatal("Can't write "<<filename);
+    const vl_unique_ptr<std::ofstream> logp(V3File::new_ofstream(filename));
+    if (logp->fail()) v3fatal("Can't write " << filename);
 
-    std::map<int,int> dist;
+    std::map<int, int> dist;
 
     V3Hash lasthash;
     int num_in_bucket = 0;
-    for (HashMmap::iterator it=begin(); 1; ++it) {
-        if (it==end() || lasthash != it->first) {
-            if (it!=end()) lasthash = it->first;
+    for (HashMmap::iterator it = begin(); 1; ++it) {
+        if (it == end() || lasthash != it->first) {
+            if (it != end()) lasthash = it->first;
             if (num_in_bucket) {
-                if (dist.find(num_in_bucket)==dist.end()) {
+                if (dist.find(num_in_bucket) == dist.end()) {
                     dist.insert(make_pair(num_in_bucket, 1));
                 } else {
                     ++dist[num_in_bucket];
@@ -174,22 +171,23 @@ void V3Hashed::dumpFile(const string& filename, bool tree) {
             }
             num_in_bucket = 0;
         }
-        if (it==end()) break;
+        if (it == end()) break;
         num_in_bucket++;
     }
-    *logp <<"\n*** STATS:\n"<<endl;
-    *logp<<"    #InBucket   Occurrences\n";
-    for (std::map<int,int>::iterator it=dist.begin(); it!=dist.end(); ++it) {
-        *logp<<"    "<<std::setw(9)<<it->first<<"  "<<std::setw(12)<<it->second<<endl;
+    *logp << "\n*** STATS:\n" << endl;
+    *logp << "    #InBucket   Occurrences\n";
+    for (std::map<int, int>::iterator it = dist.begin(); it != dist.end(); ++it) {
+        *logp << "    " << std::setw(9) << it->first << "  " << std::setw(12) << it->second
+              << endl;
     }
 
-    *logp <<"\n*** Dump:\n"<<endl;
-    for (HashMmap::iterator it=begin(); it!=end(); ++it) {
+    *logp << "\n*** Dump:\n" << endl;
+    for (HashMmap::iterator it = begin(); it != end(); ++it) {
         if (lasthash != it->first) {
             lasthash = it->first;
-            *logp <<"    "<<it->first<<endl;
+            *logp << "    " << it->first << endl;
         }
-        *logp <<"\t"<<it->second<<endl;
+        *logp << "\t" << it->second << endl;
         // Dumping the entire tree may make nearly N^2 sized dumps,
         // because the nodes under this one may also be in the hash table!
         if (tree) it->second->dumpTree(*logp, "    ");
@@ -197,14 +195,13 @@ void V3Hashed::dumpFile(const string& filename, bool tree) {
 }
 
 V3Hashed::iterator V3Hashed::findDuplicate(AstNode* nodep, V3HashedUserSame* checkp) {
-    UINFO(8,"   findD "<<nodep<<endl);
+    UINFO(8, "   findD " << nodep << endl);
     UASSERT_OBJ(nodep->user4p(), nodep, "Called findDuplicate on non-hashed node");
-    std::pair<HashMmap::iterator,HashMmap::iterator> eqrange
+    std::pair<HashMmap::iterator, HashMmap::iterator> eqrange
         = mmap().equal_range(nodeHash(nodep));
     for (HashMmap::iterator eqit = eqrange.first; eqit != eqrange.second; ++eqit) {
         AstNode* node2p = eqit->second;
-        if (nodep != node2p
-            && (!checkp || checkp->isSame(nodep, node2p))
+        if (nodep != node2p && (!checkp || checkp->isSame(nodep, node2p))
             && sameNodes(nodep, node2p)) {
             return eqit;
         }
