@@ -52,15 +52,16 @@ private:
         uint32_t m_savedCount;
         AstNode* m_nodep;
         InstrCountVisitor* m_visitor;
+
     public:
         // CONSTRUCTORS
         VisitBase(InstrCountVisitor* visitor, AstNode* nodep)
-            : m_nodep(nodep), m_visitor(visitor) {
+            : m_nodep(nodep)
+            , m_visitor(visitor) {
             m_savedCount = m_visitor->startVisitBase(nodep);
         }
-        ~VisitBase() {
-            m_visitor->endVisitBase(m_savedCount, m_nodep);
-        }
+        ~VisitBase() { m_visitor->endVisitBase(m_savedCount, m_nodep); }
+
     private:
         VL_UNCOPYABLE(VisitBase);
     };
@@ -68,13 +69,12 @@ private:
 public:
     // CONSTRUCTORS
     InstrCountVisitor(AstNode* nodep, bool assertNoDups, std::ostream* osp)
-        : m_instrCount(0),
-          m_startNodep(nodep),
-          m_tracingCall(false),
-          m_inCFunc(false),
-          m_assertNoDups(assertNoDups),
-          m_osp(osp)
-        {
+        : m_instrCount(0)
+        , m_startNodep(nodep)
+        , m_tracingCall(false)
+        , m_inCFunc(false)
+        , m_assertNoDups(assertNoDups)
+        , m_osp(osp) {
         if (nodep) iterate(nodep);
     }
     virtual ~InstrCountVisitor() {}
@@ -98,7 +98,7 @@ private:
             // collisions in CFuncs.
             UASSERT_OBJ(!nodep->user5p(), nodep,
                         "Node originally inserted below logic vertex "
-                        <<static_cast<AstNode*>(nodep->user5p()));
+                            << static_cast<AstNode*>(nodep->user5p()));
             nodep->user5p(const_cast<void*>(reinterpret_cast<const void*>(m_startNodep)));
         }
 
@@ -110,13 +110,12 @@ private:
         return savedCount;
     }
     void endVisitBase(uint32_t savedCount, AstNode* nodep) {
-        UINFO(8, "cost "<<std::setw(6)<<std::left<<m_instrCount
-              <<"  "<<nodep<<endl);
+        UINFO(8, "cost " << std::setw(6) << std::left << m_instrCount << "  " << nodep << endl);
         markCost(nodep);
         m_instrCount += savedCount;
     }
     void markCost(AstNode* nodep) {
-        if (m_osp) nodep->user4(m_instrCount+1);  // Else don't mark to avoid writeback
+        if (m_osp) nodep->user4(m_instrCount + 1);  // Else don't mark to avoid writeback
     }
 
     // VISITORS
@@ -275,7 +274,8 @@ private:
 public:
     // CONSTRUCTORS
     InstrCountDumpVisitor(AstNode* nodep, std::ostream* osp)
-        : m_osp(osp), m_depth(0) {
+        : m_osp(osp)
+        , m_depth(0) {
         // No check for NULL output, so...
         UASSERT_OBJ(osp, nodep, "Don't call if not dumping");
         if (nodep) iterate(nodep);
@@ -284,13 +284,12 @@ public:
 
 private:
     // METHODS
-    string indent() { return string(m_depth, ':')+" "; }
+    string indent() { return string(m_depth, ':') + " "; }
     virtual void visit(AstNode* nodep) VL_OVERRIDE {
         ++m_depth;
         if (unsigned costPlus1 = nodep->user4()) {
-            *m_osp <<"  "<<indent()
-                   <<"cost "<<std::setw(6)<<std::left<<(costPlus1-1)
-                   <<"  "<<nodep<<endl;
+            *m_osp << "  " << indent() << "cost " << std::setw(6) << std::left << (costPlus1 - 1)
+                   << "  " << nodep << endl;
             iterateChildren(nodep);
         }
         --m_depth;
