@@ -38,38 +38,40 @@
 class LinkJumpVisitor : public AstNVisitor {
 private:
     // TYPES
-    typedef std::vector<AstBegin*> BeginStack;
+    typedef std::vector<AstNodeBlock*> BlockStack;
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    AstNodeFTask*       m_ftaskp;       // Current function/task
-    AstWhile*           m_loopp;        // Current loop
-    bool                m_loopInc;      // In loop increment
-    int                 m_modRepeatNum;  // Repeat counter
-    BeginStack          m_beginStack;   // All begin blocks above current node
+    AstNodeModule* m_modp;  // Current module
+    AstNodeFTask* m_ftaskp;  // Current function/task
+    AstWhile* m_loopp;  // Current loop
+    bool m_loopInc;  // In loop increment
+    int m_modRepeatNum;  // Repeat counter
+    BlockStack m_blockStack;  // All begin blocks above current node
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     AstJumpLabel* findAddLabel(AstNode* nodep, bool endOfIter) {
         // Put label under given node, and if WHILE optionally at end of iteration
-        UINFO(4,"Create label for "<<nodep<<endl);
+        UINFO(4, "Create label for " << nodep << endl);
         if (VN_IS(nodep, JumpLabel)) return VN_CAST(nodep, JumpLabel);  // Done
 
         AstNode* underp = NULL;
-        bool     under_and_next = true;
-        if (VN_IS(nodep, Begin)) underp = VN_CAST(nodep, Begin)->stmtsp();
-        else if (VN_IS(nodep, NodeFTask)) underp = VN_CAST(nodep, NodeFTask)->stmtsp();
-        else if (VN_IS(nodep, While)) {
+        bool under_and_next = true;
+        if (VN_IS(nodep, NodeBlock)) {
+            underp = VN_CAST(nodep, NodeBlock)->stmtsp();
+        } else if (VN_IS(nodep, NodeFTask)) {
+            underp = VN_CAST(nodep, NodeFTask)->stmtsp();
+        } else if (VN_IS(nodep, While)) {
             if (endOfIter) {
                 // Note we jump to end of bodysp; a FOR loop has its
                 // increment under incsp() which we don't skip
                 underp = VN_CAST(nodep, While)->bodysp();
             } else {
-                underp = nodep; under_and_next = false;  // IE we skip the entire while
+                underp = nodep;
+                under_and_next = false;  // IE we skip the entire while
             }
-        }
-        else {
+        } else {
             nodep->v3fatalSrc("Unknown jump point for break/disable/continue");
             return NULL;
         }
@@ -78,7 +80,7 @@ private:
         // see t_func_return test.
         while (underp && VN_IS(underp, Var)) underp = underp->nextp();
         UASSERT_OBJ(underp, nodep, "Break/disable/continue not under expected statement");
-        UINFO(5,"  Underpoint is "<<underp<<endl);
+        UINFO(5, "  Underpoint is " << underp << endl);
 
         if (VN_IS(underp, JumpLabel)) {
             return VN_CAST(underp, JumpLabel);
@@ -86,17 +88,18 @@ private:
             AstJumpLabel* labelp = new AstJumpLabel(nodep->fileline(), NULL);
 
             AstNRelinker repHandle;
-            if (under_and_next) underp->unlinkFrBackWithNext(&repHandle);
-            else underp->unlinkFrBack(&repHandle);
+            if (under_and_next) {
+                underp->unlinkFrBackWithNext(&repHandle);
+            } else {
+                underp->unlinkFrBack(&repHandle);
+            }
             repHandle.relink(labelp);
 
             labelp->addStmtsp(underp);
             // Keep any AstVars under the function not under the new JumpLabel
-            for (AstNode* nextp, *varp=underp; varp; varp = nextp) {
+            for (AstNode *nextp, *varp = underp; varp; varp = nextp) {
                 nextp = varp->nextp();
-                if (VN_IS(varp, Var)) {
-                    labelp->addPrev(varp->unlinkFrBack());
-                }
+                if (VN_IS(varp, Var)) labelp->addPrev(varp->unlinkFrBack());
             }
             return labelp;
         }
@@ -120,40 +123,35 @@ private:
         iterateChildren(nodep);
         m_ftaskp = NULL;
     }
-    virtual void visit(AstBegin* nodep) VL_OVERRIDE {
-        UINFO(8,"  "<<nodep<<endl);
-        m_beginStack.push_back(nodep);
+    virtual void visit(AstNodeBlock* nodep) VL_OVERRIDE {
+        UINFO(8, "  " << nodep << endl);
+        m_blockStack.push_back(nodep);
         iterateChildren(nodep);
-        m_beginStack.pop_back();
+        m_blockStack.pop_back();
     }
     virtual void visit(AstRepeat* nodep) VL_OVERRIDE {
         // So later optimizations don't need to deal with them,
         //    REPEAT(count,body) -> loop=count,WHILE(loop>0) { body, loop-- }
         // Note var can be signed or unsigned based on original number.
         AstNode* countp = nodep->countp()->unlinkFrBackWithNext();
-        string name = string("__Vrepeat")+cvtToStr(m_modRepeatNum++);
+        string name = string("__Vrepeat") + cvtToStr(m_modRepeatNum++);
         // Spec says value is integral, if negative is ignored
         AstVar* varp = new AstVar(nodep->fileline(), AstVarType::BLOCKTEMP, name,
                                   nodep->findSigned32DType());
         varp->usedLoopIdx(true);
         m_modp->addStmtp(varp);
         AstNode* initsp = new AstAssign(nodep->fileline(),
-                                        new AstVarRef(nodep->fileline(), varp, true),
-                                        countp);
-        AstNode* decp = new AstAssign(nodep->fileline(),
-                                      new AstVarRef(nodep->fileline(), varp, true),
-                                      new AstSub(nodep->fileline(),
-                                                 new AstVarRef(nodep->fileline(), varp, false),
-                                                 new AstConst(nodep->fileline(), 1)));
+                                        new AstVarRef(nodep->fileline(), varp, true), countp);
+        AstNode* decp = new AstAssign(
+            nodep->fileline(), new AstVarRef(nodep->fileline(), varp, true),
+            new AstSub(nodep->fileline(), new AstVarRef(nodep->fileline(), varp, false),
+                       new AstConst(nodep->fileline(), 1)));
         AstNode* zerosp = new AstConst(nodep->fileline(), AstConst::Signed32(), 0);
-        AstNode* condp = new AstGtS(nodep->fileline(),
-                                    new AstVarRef(nodep->fileline(), varp, false),
-                                    zerosp);
-        AstNode* bodysp = nodep->bodysp(); if (bodysp) bodysp->unlinkFrBackWithNext();
-        AstNode* newp = new AstWhile(nodep->fileline(),
-                                     condp,
-                                     bodysp,
-                                     decp);
+        AstNode* condp
+            = new AstGtS(nodep->fileline(), new AstVarRef(nodep->fileline(), varp, false), zerosp);
+        AstNode* bodysp = nodep->bodysp();
+        if (bodysp) bodysp->unlinkFrBackWithNext();
+        AstNode* newp = new AstWhile(nodep->fileline(), condp, bodysp, decp);
         initsp = initsp->addNext(newp);
         newp = initsp;
         nodep->replaceWith(newp);
@@ -178,67 +176,75 @@ private:
         AstFunc* funcp = VN_CAST(m_ftaskp, Func);
         if (!m_ftaskp) {
             nodep->v3error("Return isn't underneath a task or function");
-        } else if (funcp  && !nodep->lhsp()) {
+        } else if (funcp && !nodep->lhsp()) {
             nodep->v3error("Return underneath a function should have return value");
-        } else if (!funcp &&  nodep->lhsp()) {
+        } else if (!funcp && nodep->lhsp()) {
             nodep->v3error("Return underneath a task shouldn't have return value");
         } else {
             if (funcp && nodep->lhsp()) {
                 // Set output variable to return value
-                nodep->addPrev(new AstAssign(nodep->fileline(),
-                                             new AstVarRef(nodep->fileline(),
-                                                           VN_CAST(funcp->fvarp(), Var), true),
-                                             nodep->lhsp()->unlinkFrBackWithNext()));
+                nodep->addPrev(new AstAssign(
+                    nodep->fileline(),
+                    new AstVarRef(nodep->fileline(), VN_CAST(funcp->fvarp(), Var), true),
+                    nodep->lhsp()->unlinkFrBackWithNext()));
             }
             // Jump to the end of the function call
             AstJumpLabel* labelp = findAddLabel(m_ftaskp, false);
             nodep->addPrev(new AstJumpGo(nodep->fileline(), labelp));
         }
-        nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
+        nodep->unlinkFrBack();
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
     virtual void visit(AstBreak* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
-        if (!m_loopp) { nodep->v3error("break isn't underneath a loop"); }
-        else {
+        if (!m_loopp) {
+            nodep->v3error("break isn't underneath a loop");
+        } else {
             // Jump to the end of the loop
             AstJumpLabel* labelp = findAddLabel(m_loopp, false);
             nodep->addNextHere(new AstJumpGo(nodep->fileline(), labelp));
         }
-        nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
+        nodep->unlinkFrBack();
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
     virtual void visit(AstContinue* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
-        if (!m_loopp) { nodep->v3error("continue isn't underneath a loop"); }
-        else {
+        if (!m_loopp) {
+            nodep->v3error("continue isn't underneath a loop");
+        } else {
             // Jump to the end of this iteration
             // If a "for" loop then need to still do the post-loop increment
             AstJumpLabel* labelp = findAddLabel(m_loopp, true);
             nodep->addNextHere(new AstJumpGo(nodep->fileline(), labelp));
         }
-        nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
+        nodep->unlinkFrBack();
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
     virtual void visit(AstDisable* nodep) VL_OVERRIDE {
-        UINFO(8,"   DISABLE "<<nodep<<endl);
+        UINFO(8, "   DISABLE " << nodep << endl);
         iterateChildren(nodep);
-        AstBegin* beginp = NULL;
-        for (BeginStack::reverse_iterator it = m_beginStack.rbegin();
-             it != m_beginStack.rend(); ++it) {
-            UINFO(9,"    UNDERBLK  "<<*it<<endl);
+        AstNodeBlock* blockp = NULL;
+        for (BlockStack::reverse_iterator it = m_blockStack.rbegin(); it != m_blockStack.rend();
+             ++it) {
+            UINFO(9, "    UNDERBLK  " << *it << endl);
             if ((*it)->name() == nodep->name()) {
-                beginp = *it;
+                blockp = *it;
                 break;
             }
         }
-        //if (debug()>=9) { UINFO(0,"\n"); beginp->dumpTree(cout, "  labeli: "); }
-        if (!beginp) { nodep->v3error("disable isn't underneath a begin with name: "
-                                      <<nodep->prettyNameQ()); }
-        else {
-            // Jump to the end of the named begin
+        // if (debug() >= 9) { UINFO(0, "\n"); blockp->dumpTree(cout, "  labeli: "); }
+        if (!blockp) {
+            nodep->v3error("disable isn't underneath a begin with name: " << nodep->prettyNameQ());
+        } else if (AstBegin* beginp = VN_CAST(blockp, Begin)) {
+            // Jump to the end of the named block
             AstJumpLabel* labelp = findAddLabel(beginp, false);
             nodep->addNextHere(new AstJumpGo(nodep->fileline(), labelp));
+        } else {
+            nodep->v3error("Unsupported: disable fork");
         }
-        nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
-        //if (debug()>=9) { UINFO(0,"\n"); beginp->dumpTree(cout, "  labelo: "); }
+        nodep->unlinkFrBack();
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
+        // if (debug() >= 9) { UINFO(0, "\n"); beginp->dumpTree(cout, "  labelo: "); }
     }
     virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (m_loopInc && nodep->varp()) nodep->varp()->usedLoopIdx(true);
@@ -263,9 +269,7 @@ public:
 // Task class functions
 
 void V3LinkJump::linkJump(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        LinkJumpVisitor bvisitor (nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { LinkJumpVisitor bvisitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("link", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
