@@ -41,24 +41,24 @@ private:
     // Cleared on netlist
     //  AstNode::user1()        -> bool.  True if processed
     //  AstNode::user2()        -> bool.  True if fileline recomputed
-    AstUser1InUse       m_inuser1;
-    AstUser2InUse       m_inuser2;
+    AstUser1InUse m_inuser1;
+    AstUser2InUse m_inuser2;
 
     // TYPES
-    typedef std::map<std::pair<void*,string>,AstTypedef*> ImplTypedefMap;
+    typedef std::map<std::pair<void*, string>, AstTypedef*> ImplTypedefMap;
     typedef std::set<FileLine*> FileLineSet;
 
     // STATE
-    AstVar*             m_varp;         // Variable we're under
-    ImplTypedefMap      m_implTypedef;  // Created typedefs for each <container,name>
-    FileLineSet         m_filelines;    // Filelines that have been seen
-    bool                m_inAlways;     // Inside an always
-    bool                m_inGenerate;   // Inside a generate
-    bool                m_needStart;    // Need start marker on lower AstParse
-    AstNodeModule*      m_valueModp;    // If set, move AstVar->valuep() initial values to this module
-    AstNodeModule*      m_modp;         // Current module
-    AstNodeFTask*       m_ftaskp;       // Current task
-    AstNodeDType*       m_dtypep;       // Current data type
+    AstVar* m_varp;  // Variable we're under
+    ImplTypedefMap m_implTypedef;  // Created typedefs for each <container,name>
+    FileLineSet m_filelines;  // Filelines that have been seen
+    bool m_inAlways;  // Inside an always
+    bool m_inGenerate;  // Inside a generate
+    bool m_needStart;  // Need start marker on lower AstParse
+    AstNodeModule* m_valueModp;  // If set, move AstVar->valuep() initial values to this module
+    AstNodeModule* m_modp;  // Current module
+    AstNodeFTask* m_ftaskp;  // Current task
+    AstNodeDType* m_dtypep;  // Current data type
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -84,8 +84,11 @@ private:
             // Create a name for the enum, to aid debug and tracing
             // This name is not guaranteed to be globally unique (due to later parameterization)
             string above;
-            if (m_modp && VN_IS(m_modp, Package)) above = m_modp->name()+"::";
-            else if (m_modp) above = m_modp->name()+".";
+            if (m_modp && VN_IS(m_modp, Package)) {
+                above = m_modp->name() + "::";
+            } else if (m_modp) {
+                above = m_modp->name() + ".";
+            }
             return above + typedefp->name();
         }
         return "";
@@ -115,16 +118,14 @@ private:
     virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         if (!nodep->user1SetOnce()) {  // Process only once.
             cleanFileline(nodep);
-            UINFO(5,"   "<<nodep<<endl);
+            UINFO(5, "   " << nodep << endl);
             AstNodeModule* upperValueModp = m_valueModp;
             m_valueModp = NULL;
             iterateChildren(nodep);
             m_valueModp = upperValueModp;
         }
     }
-    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
-        visitIterateNodeDType(nodep);
-    }
+    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE { visitIterateNodeDType(nodep); }
     virtual void visit(AstEnumDType* nodep) VL_OVERRIDE {
         if (nodep->name() == "") {
             nodep->name(nameFromTypedef(nodep));  // Might still remain ""
@@ -142,7 +143,7 @@ private:
         cleanFileline(nodep);
         iterateChildren(nodep);
         if (nodep->rangep()) {
-            if (!VN_IS(nodep->rangep()->msbp(), Const)
+            if (!VN_IS(nodep->rangep()->msbp(), Const)  //
                 || !VN_IS(nodep->rangep()->lsbp(), Const)) {
                 nodep->v3error("Enum ranges must be integral, per spec");
             }
@@ -151,18 +152,19 @@ private:
             int increment = (msb > lsb) ? -1 : 1;
             int offset_from_init = 0;
             AstNode* addp = NULL;
-            for (int i=msb; i!=(lsb+increment); i+=increment, offset_from_init++) {
+            for (int i = msb; i != (lsb + increment); i += increment, offset_from_init++) {
                 string name = nodep->name() + cvtToStr(i);
                 AstNode* valuep = NULL;
-                if (nodep->valuep()) valuep = new AstAdd
-                                         (nodep->fileline(),
-                                          nodep->valuep()->cloneTree(true),
-                                          new AstConst(nodep->fileline(),
-                                                       AstConst::Unsized32(),
-                                                       offset_from_init));
+                if (nodep->valuep())
+                    valuep = new AstAdd(
+                        nodep->fileline(), nodep->valuep()->cloneTree(true),
+                        new AstConst(nodep->fileline(), AstConst::Unsized32(), offset_from_init));
                 AstNode* newp = new AstEnumItem(nodep->fileline(), name, NULL, valuep);
-                if (addp) addp = addp->addNextNull(newp);
-                else addp = newp;
+                if (addp) {
+                    addp = addp->addNextNull(newp);
+                } else {
+                    addp = newp;
+                }
             }
             nodep->replaceWith(addp);
             VL_DO_DANGLING(nodep->deleteTree(), nodep);
@@ -175,15 +177,15 @@ private:
             // It's a parameter type. Use a different node type for this.
             AstNodeDType* dtypep = VN_CAST(nodep->valuep(), NodeDType);
             if (!dtypep) {
-                nodep->v3error("Parameter type's initial value isn't a type: "
-                               <<nodep->prettyNameQ());
+                nodep->v3error(
+                    "Parameter type's initial value isn't a type: " << nodep->prettyNameQ());
                 nodep->unlinkFrBack();
             } else {
                 dtypep->unlinkFrBack();
-                AstNode* newp = new AstParamTypeDType(nodep->fileline(),
-                                                      nodep->varType(), nodep->name(),
-                                                      VFlagChildDType(), dtypep);
-                nodep->replaceWith(newp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+                AstNode* newp = new AstParamTypeDType(nodep->fileline(), nodep->varType(),
+                                                      nodep->name(), VFlagChildDType(), dtypep);
+                nodep->replaceWith(newp);
+                VL_DO_DANGLING(nodep->deleteTree(), nodep);
             }
             return;
         }
@@ -195,18 +197,15 @@ private:
             switch (nodep->varType()) {
             case AstVarType::VAR:
             case AstVarType::PORT:
-            case AstVarType::WIRE:
-                nodep->sigUserRWPublic(true);
-                break;
+            case AstVarType::WIRE: nodep->sigUserRWPublic(true); break;
             default: break;
             }
         }
 
         // We used modTrace before leveling, and we may now
         // want to turn it off now that we know the levelizations
-        if (v3Global.opt.traceDepth()
-            && m_modp
-            && (m_modp->level()-1) > v3Global.opt.traceDepth()) {
+        if (v3Global.opt.traceDepth() && m_modp
+            && (m_modp->level() - 1) > v3Global.opt.traceDepth()) {
             m_modp->modTrace(false);
             nodep->trace(false);
         }
@@ -219,27 +218,30 @@ private:
         if (nodep->valuep()) {
             // A variable with an = value can be three things:
             FileLine* fl = nodep->valuep()->fileline();
-            // 1. Parameters and function inputs: It's a default to use if not overridden
             if (nodep->isParam() || (m_ftaskp && nodep->isNonOutput())) {
-            }
-            else if (!m_ftaskp && nodep->isNonOutput()) {
-                nodep->v3error("Unsupported: Default value on module input: "
-                               <<nodep->prettyNameQ());
+                // 1. Parameters and function inputs: It's a default to use if not overridden
+            } else if (VN_IS(m_modp, Class)) {
+                // 2. Class member init become initials (as might call functions)
+                // later move into class constructor
+                nodep->addNextHere(
+                    new AstInitial(fl, new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
+                                                     nodep->valuep()->unlinkFrBack())));
+            } else if (!m_ftaskp && nodep->isNonOutput()) {
+                nodep->v3error(
+                    "Unsupported: Default value on module input: " << nodep->prettyNameQ());
                 nodep->valuep()->unlinkFrBack()->deleteTree();
-            }  // 2. Under modules, it's an initial value to be loaded at time 0 via an AstInitial
+            }  // 3. Under modules, it's an initial value to be loaded at time 0 via an AstInitial
             else if (m_valueModp) {
                 // Making an AstAssign (vs AstAssignW) to a wire is an error, suppress it
                 FileLine* newfl = new FileLine(fl);
                 newfl->warnOff(V3ErrorCode::PROCASSWIRE, true);
-                nodep->addNextHere
-                    (new AstInitial
-                     (newfl, new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), true),
-                                           nodep->valuep()->unlinkFrBack())));
-            }  // 3. Under blocks, it's an initial value to be under an assign
+                nodep->addNextHere(new AstInitial(
+                    newfl, new AstAssign(newfl, new AstVarRef(newfl, nodep->name(), true),
+                                         nodep->valuep()->unlinkFrBack())));
+            }  // 4. Under blocks, it's an initial value to be under an assign
             else {
-                nodep->addNextHere
-                    (new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
-                                   nodep->valuep()->unlinkFrBack()));
+                nodep->addNextHere(new AstAssign(fl, new AstVarRef(fl, nodep->name(), true),
+                                                 nodep->valuep()->unlinkFrBack()));
             }
         }
         if (nodep->isIfaceRef() && !nodep->isIfaceParent()) {
@@ -247,7 +249,9 @@ private:
             // haven't made additional ones for interconnect yet, so assert is simple
             // What breaks later is we don't have a Scope/Cell representing
             // the interface to attach to
-            if (m_modp->level()<=2) nodep->v3error("Unsupported: Interfaced port on top level module");
+            if (m_modp->level() <= 2) {
+                nodep->v3error("Unsupported: Interfaced port on top level module");
+            }
         }
     }
 
@@ -259,69 +263,61 @@ private:
             UASSERT_OBJ(typep, nodep, "Attribute not attached to typedef");
             typep->attrPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCK) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCK) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             nodep->v3warn(DEPRECATED, "sc_clock is deprecated and will be removed");
             m_varp->attrScClocked(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCK_ENABLE) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCK_ENABLE) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClockEn(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
-            m_varp->sigUserRWPublic(true); m_varp->sigModPublic(true);
+            m_varp->sigUserRWPublic(true);
+            m_varp->sigModPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRWPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RD) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RD) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRdPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RW) {
+        } else if (nodep->attrType() == AstAttrType::VAR_PUBLIC_FLAT_RW) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->sigUserRWPublic(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_ISOLATE_ASSIGNMENTS) {
+        } else if (nodep->attrType() == AstAttrType::VAR_ISOLATE_ASSIGNMENTS) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrIsolateAssign(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_SFORMAT) {
+        } else if (nodep->attrType() == AstAttrType::VAR_SFORMAT) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrSFormat(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_SPLIT_VAR) {
+        } else if (nodep->attrType() == AstAttrType::VAR_SPLIT_VAR) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             if (!VN_IS(m_modp, Module)) {
-                m_varp->v3warn(SPLITVAR, m_varp->prettyNameQ() << " has split_var metacomment, "
-                               "but will not be split because it is not declared in a module.");
+                m_varp->v3warn(
+                    SPLITVAR,
+                    m_varp->prettyNameQ()
+                        << " has split_var metacomment, "
+                           "but will not be split because it is not declared in a module.");
             } else {
                 m_varp->attrSplitVar(true);
             }
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_SC_BV) {
+        } else if (nodep->attrType() == AstAttrType::VAR_SC_BV) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrScBv(true);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_CLOCKER) {
+        } else if (nodep->attrType() == AstAttrType::VAR_CLOCKER) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClocker(VVarAttrClocker::CLOCKER_YES);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
-        }
-        else if (nodep->attrType() == AstAttrType::VAR_NO_CLOCKER) {
+        } else if (nodep->attrType() == AstAttrType::VAR_NO_CLOCKER) {
             UASSERT_OBJ(m_varp, nodep, "Attribute not attached to variable");
             m_varp->attrClocker(VVarAttrClocker::CLOCKER_NO);
             VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
@@ -345,36 +341,38 @@ private:
 
     virtual void visit(AstDefImplicitDType* nodep) VL_OVERRIDE {
         cleanFileline(nodep);
-        UINFO(8,"   DEFIMPLICIT "<<nodep<<endl);
+        UINFO(8, "   DEFIMPLICIT " << nodep << endl);
         // Must remember what names we've already created, and combine duplicates
         // so that for "var enum {...} a,b" a & b will share a common typedef
         // Unique name space under each containerp() so that an addition of
         // a new type won't change every verilated module.
         AstTypedef* defp = NULL;
-        ImplTypedefMap::iterator it = m_implTypedef.find(make_pair(nodep->containerp(), nodep->name()));
+        ImplTypedefMap::iterator it
+            = m_implTypedef.find(make_pair(nodep->containerp(), nodep->name()));
         if (it != m_implTypedef.end()) {
             defp = it->second;
         } else {
             // Definition must be inserted right after the variable (etc) that needed it
             // AstVar, AstTypedef, AstNodeFTask are common containers
             AstNode* backp = nodep->backp();
-            for (; backp; backp=backp->backp()) {
-                if (VN_IS(backp, Var)) break;
-                else if (VN_IS(backp, Typedef)) break;
-                else if (VN_IS(backp, NodeFTask)) break;
+            for (; backp; backp = backp->backp()) {
+                if (VN_IS(backp, Var) || VN_IS(backp, Typedef) || VN_IS(backp, NodeFTask)) break;
             }
             UASSERT_OBJ(backp, nodep,
                         "Implicit enum/struct type created under unexpected node type");
-            AstNodeDType* dtypep = nodep->childDTypep(); dtypep->unlinkFrBack();
-            if (VN_IS(backp, Typedef)) {  // A typedef doesn't need us to make yet another level of typedefing
+            AstNodeDType* dtypep = nodep->childDTypep();
+            dtypep->unlinkFrBack();
+            if (VN_IS(backp, Typedef)) {
+                // A typedef doesn't need us to make yet another level of typedefing
                 // For typedefs just remove the AstRefDType level of abstraction
                 nodep->replaceWith(dtypep);
                 VL_DO_DANGLING(nodep->deleteTree(), nodep);
                 return;
             } else {
-                defp = new AstTypedef(nodep->fileline(), nodep->name(), NULL,
-                                      VFlagChildDType(), dtypep);
-                m_implTypedef.insert(make_pair(make_pair(nodep->containerp(), defp->name()), defp));
+                defp = new AstTypedef(nodep->fileline(), nodep->name(), NULL, VFlagChildDType(),
+                                      dtypep);
+                m_implTypedef.insert(
+                    make_pair(make_pair(nodep->containerp(), defp->name()), defp));
                 backp->addNextHere(defp);
             }
         }
@@ -385,19 +383,22 @@ private:
     virtual void visit(AstForeach* nodep) VL_OVERRIDE {
         // FOREACH(array,loopvars,body)
         // -> BEGIN(declare vars, loopa=lowest; WHILE(loopa<=highest, ... body))
-        //nodep->dumpTree(cout, "-foreach-old:");
+        // nodep->dumpTree(cout, "-foreach-old:");
         AstNode* newp = nodep->bodysp()->unlinkFrBackWithNext();
         AstNode* arrayp = nodep->arrayp();
         int dimension = 1;
         // Must do innermost (last) variable first
         AstNode* firstVarsp = nodep->varsp()->unlinkFrBackWithNext();
         AstNode* lastVarsp = firstVarsp;
-        while (lastVarsp->nextp()) { lastVarsp = lastVarsp->nextp(); dimension++; }
-        for (AstNode* varsp = lastVarsp; varsp; varsp=varsp->backp()) {
-            UINFO(9,"foreachVar "<<varsp<<endl);
+        while (lastVarsp->nextp()) {
+            lastVarsp = lastVarsp->nextp();
+            dimension++;
+        }
+        for (AstNode* varsp = lastVarsp; varsp; varsp = varsp->backp()) {
+            UINFO(9, "foreachVar " << varsp << endl);
             FileLine* fl = varsp->fileline();
-            AstNode* varp = new AstVar(fl, AstVarType::BLOCKTEMP,
-                                       varsp->name(), nodep->findSigned32DType());
+            AstNode* varp
+                = new AstVar(fl, AstVarType::BLOCKTEMP, varsp->name(), nodep->findSigned32DType());
             // These will be the left and right dimensions and size of the array:
             AstNode* leftp = new AstAttrOf(fl, AstAttrType::DIM_LEFT,
                                            new AstVarRef(fl, arrayp->name(), false),
@@ -410,19 +411,16 @@ private:
                                            new AstConst(fl, dimension));
             AstNode* stmtsp = varp;
             // Assign left-dimension into the loop var:
-            stmtsp->addNext(new AstAssign
-                            (fl, new AstVarRef(fl, varp->name(), true), leftp));
+            stmtsp->addNext(new AstAssign(fl, new AstVarRef(fl, varp->name(), true), leftp));
             // This will turn into a constant bool for static arrays
             AstNode* notemptyp = new AstGt(fl, sizep, new AstConst(fl, 0));
             // This will turn into a bool constant, indicating whether
             // we count the loop variable up or down:
-            AstNode* countupp = new AstLte(fl, leftp->cloneTree(true),
-                                           rightp->cloneTree(true));
+            AstNode* countupp = new AstLte(fl, leftp->cloneTree(true), rightp->cloneTree(true));
             AstNode* comparep = new AstCond(
                 fl, countupp->cloneTree(true),
                 // Left increments up to right
-                new AstLte(fl, new AstVarRef(fl, varp->name(), false),
-                           rightp->cloneTree(true)),
+                new AstLte(fl, new AstVarRef(fl, varp->name(), false), rightp->cloneTree(true)),
                 // Left decrements down to right
                 new AstGte(fl, new AstVarRef(fl, varp->name(), false), rightp));
             // This will reduce to comparep for static arrays
@@ -430,16 +428,15 @@ private:
             AstNode* incp = new AstAssign(
                 fl, new AstVarRef(fl, varp->name(), true),
                 new AstAdd(fl, new AstVarRef(fl, varp->name(), false),
-                           new AstCond(fl, countupp,
-                                       new AstConst(fl, 1),
-                                       new AstConst(fl, -1))));
+                           new AstCond(fl, countupp, new AstConst(fl, 1), new AstConst(fl, -1))));
             stmtsp->addNext(new AstWhile(fl, condp, newp, incp));
             newp = new AstBegin(nodep->fileline(), "", stmtsp, false, true);
             dimension--;
         }
-        //newp->dumpTree(cout, "-foreach-new:");
+        // newp->dumpTree(cout, "-foreach-new:");
         VL_DO_DANGLING(firstVarsp->deleteTree(), firstVarsp);
-        nodep->replaceWith(newp); VL_DO_DANGLING(nodep->deleteTree(), nodep);
+        nodep->replaceWith(newp);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
     virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
@@ -466,23 +463,15 @@ private:
         iterateChildren(nodep);
         m_valueModp = upperValueModp;
     }
-    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
-    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
+    virtual void visit(AstFinal* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         m_inAlways = true;
         visitIterateNoValueMod(nodep);
         m_inAlways = false;
     }
-    virtual void visit(AstCover* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
-    virtual void visit(AstRestrict* nodep) VL_OVERRIDE {
-        visitIterateNoValueMod(nodep);
-    }
+    virtual void visit(AstCover* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
+    virtual void visit(AstRestrict* nodep) VL_OVERRIDE { visitIterateNoValueMod(nodep); }
 
     virtual void visit(AstBegin* nodep) VL_OVERRIDE {
         V3Config::applyCoverageBlock(m_modp, nodep);
@@ -496,19 +485,50 @@ private:
         // It's not FOR(BEGIN(...)) but we earlier changed it to BEGIN(FOR(...))
         if (nodep->genforp() && nodep->name() == "") {
             nodep->name("genblk");
-        }
-        else if (nodep->generate() && nodep->name() == ""
-            && (VN_IS(backp, CaseItem) || VN_IS(backp, GenIf))
-            && !nestedIf) {
+        } else if (nodep->generate() && nodep->name() == ""
+                   && (VN_IS(backp, CaseItem) || VN_IS(backp, GenIf)) && !nestedIf) {
             nodep->name("genblk");
         }
         iterateChildren(nodep);
     }
+    virtual void visit(AstFork* nodep) VL_OVERRIDE {
+        if (v3Global.opt.bboxUnsup()) {
+            AstBegin* newp
+                = new AstBegin(nodep->fileline(), nodep->name(), nodep->stmtsp()->unlinkFrBack());
+            nodep->replaceWith(newp);
+            VL_DO_DANGLING(nodep->deleteTree(), nodep);
+        } else {
+            nodep->v3error("Unsupported: fork statements");
+            // TBD might support only normal join, if so complain about other join flavors
+        }
+    }
     virtual void visit(AstCase* nodep) VL_OVERRIDE {
         V3Config::applyCase(nodep);
         cleanFileline(nodep);
         iterateChildren(nodep);
     }
+    virtual void visit(AstPrintTimeScale* nodep) VL_OVERRIDE {
+        // Inlining may change hierarchy, so just save timescale where needed
+        iterateChildren(nodep);
+        nodep->name(m_modp->name());
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstSFormatF* nodep) VL_OVERRIDE {
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTime* nodep) VL_OVERRIDE {
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTimeD* nodep) VL_OVERRIDE {
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
+    virtual void visit(AstTimeImport* nodep) VL_OVERRIDE {
+        iterateChildren(nodep);
+        nodep->timeunit(m_modp->timeunit());
+    }
 
     virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // Default: Just iterate
@@ -536,9 +556,7 @@ public:
 // Link class functions
 
 void V3LinkParse::linkParse(AstNetlist* rootp) {
-    UINFO(4,__FUNCTION__<<": "<<endl);
-    {
-        LinkParseVisitor visitor(rootp);
-    }  // Destruct before checking
+    UINFO(4, __FUNCTION__ << ": " << endl);
+    { LinkParseVisitor visitor(rootp); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("linkparse", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 6);
 }
