@@ -41,9 +41,9 @@
 //======================================================================
 // Globals
 
-V3ParseImp*     V3ParseImp::s_parsep = NULL;
+V3ParseImp* V3ParseImp::s_parsep = NULL;
 
-int             V3ParseSym::s_anonNum = 0;
+int V3ParseSym::s_anonNum = 0;
 
 extern void yyerror(const char*);
 extern void yyerrorf(const char* format, ...);
@@ -63,7 +63,10 @@ V3ParseImp::~V3ParseImp() {
     lexDestroy();
     parserClear();
 
-    if (debug()>=9) { UINFO(0,"~V3ParseImp\n"); symp()->dump(cout, "-vpi: "); }
+    if (debug() >= 9) {
+        UINFO(0, "~V3ParseImp\n");
+        symp()->dump(cout, "-vpi: ");
+    }
 }
 
 //######################################################################
@@ -73,7 +76,7 @@ void V3ParseImp::ppline(const char* textp) {
     // Handle `line directive
     FileLine* prevFl = copyOrSameFileLine();
     int enterExit;
-    fileline()->lineDirective(textp, enterExit/*ref*/);
+    fileline()->lineDirective(textp, enterExit /*ref*/);
     if (enterExit == 1) {  // Enter
         fileline()->parent(prevFl);
     } else if (enterExit == 2) {  // Exit
@@ -83,9 +86,45 @@ void V3ParseImp::ppline(const char* textp) {
     }
 }
 
-void V3ParseImp::verilatorCmtLintSave() {
-    m_lintState.push_back(*parsep()->fileline());
+void V3ParseImp::timescalePreproc(FileLine* fl, const char* textp) {
+    // Parse `timescale of <number><units> / <number><units>
+    VTimescale unit;
+    VTimescale prec;
+    VTimescale::parseSlashed(fl, textp, unit /*ref*/, prec /*ref*/);
+    m_timeLastUnit = v3Global.opt.timeComputeUnit(unit);
+    v3Global.rootp()->timeprecisionMerge(fileline(), prec);
 }
+void V3ParseImp::timescaleMod(FileLine* fl, AstNodeModule* modp, bool unitSet, double unitVal,
+                              bool precSet, double precVal) {
+    VTimescale unit(VTimescale::NONE);
+    if (unitSet) {
+        bool bad;
+        unit = VTimescale(unitVal, bad /*ref*/);
+        if (bad) {
+            UINFO(1, "Value = " << unitVal << endl);
+            fl->v3error("timeunit illegal value");
+        }
+    }
+    VTimescale prec(VTimescale::NONE);
+    if (precSet) {
+        bool bad;
+        prec = VTimescale(precVal, bad /*ref*/);
+        if (bad) {
+            UINFO(1, "Value = " << precVal << endl);
+            fl->v3error("timeprecision illegal value");
+        }
+    }
+    if (!unit.isNone()) {
+        if (modp) {
+            modp->timeunit(v3Global.opt.timeComputeUnit(unit));
+        } else {
+            fl->v3error("timeunit/timeprecision not under a module");
+        }
+    }
+    v3Global.rootp()->timeprecisionMerge(fileline(), prec);
+}
+
+void V3ParseImp::verilatorCmtLintSave() { m_lintState.push_back(*parsep()->fileline()); }
 
 void V3ParseImp::verilatorCmtLintRestore() {
     if (m_lintState.empty()) {
@@ -104,7 +143,7 @@ void V3ParseImp::verilatorCmtLint(const char* textp, bool warnOff) {
     while (*sp && isspace(*sp)) sp++;
     string msg = sp;
     string::size_type pos;
-    if ((pos = msg.find('*')) != string::npos) { msg.erase(pos); }
+    if ((pos = msg.find('*')) != string::npos) msg.erase(pos);
     if (!(parsep()->fileline()->warnOff(msg, warnOff))) {
         if (!parsep()->optFuture(msg)) {
             yyerrorf("Unknown verilator lint message code: %s, in %s", msg.c_str(), textp);
@@ -117,16 +156,10 @@ void V3ParseImp::verilatorCmtBad(const char* textp) {
     if (cmtparse.substr(0, strlen("/*verilator")) == "/*verilator") {
         cmtparse.replace(0, strlen("/*verilator"), "");
     }
-    while (isspace(cmtparse[0])) {
-        cmtparse.replace(0, 1, "");
-    }
+    while (isspace(cmtparse[0])) cmtparse.replace(0, 1, "");
     string cmtname;
-    for (int i = 0; isalnum(cmtparse[i]); i++) {
-        cmtname += cmtparse[i];
-    }
-    if (!parsep()->optFuture(cmtname)) {
-        yyerrorf("Unknown verilator comment: %s", textp);
-    }
+    for (int i = 0; isalnum(cmtparse[i]); i++) { cmtname += cmtparse[i]; }
+    if (!parsep()->optFuture(cmtname)) yyerrorf("Unknown verilator comment: %s", textp);
 }
 
 void V3ParseImp::errorPreprocDirective(const char* textp) {
@@ -140,8 +173,9 @@ void V3ParseImp::errorPreprocDirective(const char* textp) {
     }
     V3PreShell::candidateDefines(&speller);
     string suggest = speller.bestCandidateMsg(textp);
-    fileline()->v3error("Define or directive not defined: '"<<textp<<"'\n"
-                        <<(suggest.empty() ? "" : fileline()->warnMore()+suggest));
+    fileline()->v3error("Define or directive not defined: '"
+                        << textp << "'\n"
+                        << (suggest.empty() ? "" : fileline()->warnMore() + suggest));
 }
 
 void V3ParseImp::tag(const char* text) {
@@ -154,24 +188,61 @@ void V3ParseImp::tag(const char* text) {
 }
 
 double V3ParseImp::parseDouble(const char* textp, size_t length, bool* successp) {
-    char* strgp = new char[length+1];
+    char* strgp = new char[length + 1];
     char* dp = strgp;
     if (successp) *successp = true;
-    for (const char* sp = textp; sp < (textp+length); ++sp) {
+    for (const char* sp = textp; sp < (textp + length); ++sp) {
         if (*sp != '_') *dp++ = *sp;
     }
     *dp++ = '\0';
     char* endp = strgp;
     double d = strtod(strgp, &endp);
-    size_t parsed_len = endp-strgp;
+    size_t parsed_len = endp - strgp;
     if (parsed_len != strlen(strgp)) {
-        if (successp) *successp = false;
-        else yyerrorf("Syntax error parsing real: %s", strgp);
+        if (successp) {
+            *successp = false;
+        } else {
+            yyerrorf("Syntax error parsing real: %s", strgp);
+        }
     }
     VL_DO_DANGLING(delete[] strgp, strgp);
     return d;
 }
 
+double V3ParseImp::parseTimenum(const char* textp) {
+    size_t length = strlen(textp);
+    char* strgp = new char[length + 1];
+    char* dp = strgp;
+    const char* sp = textp;
+    for (; isdigit(*sp) || *sp == '_' || *sp == '.'; ++sp) {
+        if (*sp != '_') *dp++ = *sp;
+    }
+    *dp++ = '\0';
+    double d = strtod(strgp, NULL);
+    string suffix(sp);
+
+    double divisor = 1;
+    if (suffix == "s") {
+        divisor = 1;
+    } else if (suffix == "ms") {
+        divisor = 1e3;
+    } else if (suffix == "us") {
+        divisor = 1e6;
+    } else if (suffix == "ns") {
+        divisor = 1e9;
+    } else if (suffix == "ps") {
+        divisor = 1e12;
+    } else if (suffix == "fs") {
+        divisor = 1e15;
+    } else {
+        // verilog.l checks the suffix for us, so this is an assert
+        v3fatalSrc("Unknown time suffix " << suffix);
+    }
+
+    VL_DO_DANGLING(delete[] strgp, strgp);
+    return d / divisor;
+}
+
 //######################################################################
 // Parser tokenization
 
@@ -179,20 +250,21 @@ size_t V3ParseImp::ppInputToLex(char* buf, size_t max_size) {
     size_t got = 0;
     while (got < max_size  // Haven't got enough
            && !m_ppBuffers.empty()) {  // And something buffered
-        string front = m_ppBuffers.front(); m_ppBuffers.pop_front();
+        string front = m_ppBuffers.front();
+        m_ppBuffers.pop_front();
         size_t len = front.length();
-        if (len > (max_size-got)) {  // Front string too big
-            string remainder = front.substr(max_size-got);
-            front = front.substr(0, max_size-got);
+        if (len > (max_size - got)) {  // Front string too big
+            string remainder = front.substr(max_size - got);
+            front = front.substr(0, max_size - got);
             m_ppBuffers.push_front(remainder);  // Put back remainder for next time
-            len = (max_size-got);
+            len = (max_size - got);
         }
-        memcpy(buf+got, front.c_str(), len);
+        memcpy(buf + got, front.c_str(), len);
         got += len;
     }
-    if (debug()>=9) {
+    if (debug() >= 9) {
         string out = string(buf, got);
-        cout<<"   inputToLex  got="<<got<<" '"<<out<<"'"<<endl;
+        cout << "   inputToLex  got=" << got << " '" << out << "'" << endl;
     }
     // Note returns 0 at EOF
     return got;
@@ -203,11 +275,15 @@ void V3ParseImp::preprocDumps(std::ostream& os) {
         V3PreShell::dumpDefines(os);
     } else {
         bool noblanks = v3Global.opt.preprocOnly() && v3Global.opt.preprocNoLine();
-        for (std::deque<string>::iterator it = m_ppBuffers.begin(); it!=m_ppBuffers.end(); ++it) {
+        for (std::deque<string>::iterator it = m_ppBuffers.begin(); it != m_ppBuffers.end();
+             ++it) {
             if (noblanks) {
                 bool blank = true;
                 for (string::iterator its = it->begin(); its != it->end(); ++its) {
-                    if (!isspace(*its) && *its!='\n') { blank = false; break; }
+                    if (!isspace(*its) && *its != '\n') {
+                        blank = false;
+                        break;
+                    }
                 }
                 if (blank) continue;
             }
@@ -220,7 +296,7 @@ void V3ParseImp::parseFile(FileLine* fileline, const string& modfilename, bool i
                            const string& errmsg) {  // "" for no error, make fake node
     string modname = V3Os::filenameNonExt(modfilename);
 
-    UINFO(2,__FUNCTION__<<": "<<modname<<(inLibrary?" [LIB]":"")<<endl);
+    UINFO(2, __FUNCTION__ << ": " << modname << (inLibrary ? " [LIB]" : "") << endl);
     m_fileline = new FileLine(fileline);
     m_fileline->newContent();
     m_inLibrary = inLibrary;
@@ -237,7 +313,8 @@ void V3ParseImp::parseFile(FileLine* fileline, const string& modfilename, bool i
 
     if (v3Global.opt.preprocOnly() || v3Global.opt.keepTempFiles()) {
         // Create output file with all the preprocessor output we buffered up
-        string vppfilename = v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"_"+modname+".vpp";
+        string vppfilename
+            = v3Global.opt.makeDir() + "/" + v3Global.opt.prefix() + "_" + modname + ".vpp";
         std::ofstream* ofp = NULL;
         std::ostream* osp;
         if (v3Global.opt.preprocOnly()) {
@@ -246,7 +323,7 @@ void V3ParseImp::parseFile(FileLine* fileline, const string& modfilename, bool i
             osp = ofp = V3File::new_ofstream(vppfilename);
         }
         if (osp->fail()) {
-            fileline->v3error("Cannot write preprocessor output: "+vppfilename);
+            fileline->v3error("Cannot write preprocessor output: " + vppfilename);
             return;
         } else {
             preprocDumps(*osp);
@@ -267,7 +344,7 @@ void V3ParseImp::parseFile(FileLine* fileline, const string& modfilename, bool i
 
 void V3ParseImp::lexFile(const string& modname) {
     // Prepare for lexing
-    UINFO(3,"Lexing "<<modname<<endl);
+    UINFO(3, "Lexing " << modname << endl);
     s_parsep = this;
     fileline()->warnResetDefault();  // Reenable warnings on each file
     lexDestroy();  // Restart from clean slate.
@@ -283,7 +360,7 @@ void V3ParseImp::lexFile(const string& modname) {
 V3Parse::V3Parse(AstNetlist* rootp, VInFilter* filterp, V3ParseSym* symp) {
     m_impp = new V3ParseImp(rootp, filterp, symp);
 }
-V3Parse::~V3Parse() {
+V3Parse::~V3Parse() {  //
     VL_DO_CLEAR(delete m_impp, m_impp = NULL);
 }
 void V3Parse::parseFile(FileLine* fileline, const string& modname, bool inLibrary,
