@@ -36,11 +36,11 @@ class V3ParseSym {
 
 private:
     // MEMBERS
-    static int  s_anonNum;              // Number of next anonymous object (parser use only)
-    VSymGraph   m_syms;                 // Graph of symbol tree
-    VSymEnt*    m_symTableNextId;       // Symbol table for next lexer lookup (parser use only)
-    VSymEnt*    m_symCurrentp;          // Active symbol table for additions/lookups
-    SymStack    m_sympStack;            // Stack of upper nodes with pending symbol tables
+    static int s_anonNum;  // Number of next anonymous object (parser use only)
+    VSymGraph m_syms;  // Graph of symbol tree
+    VSymEnt* m_symTableNextId;  // Symbol table for next lexer lookup (parser use only)
+    VSymEnt* m_symCurrentp;  // Active symbol table for additions/lookups
+    SymStack m_sympStack;  // Stack of upper nodes with pending symbol tables
 
 public:
     // CONSTRUCTORS
@@ -74,15 +74,14 @@ public:
     }
     void nextId(AstNode* entp) {
         if (entp) {
-            UINFO(9,"symTableNextId under "<<entp<<"-"<<entp->type().ascii()<<endl);
+            UINFO(9, "symTableNextId under " << entp << "-" << entp->type().ascii() << endl);
             m_symTableNextId = getTable(entp);
-        }
-        else {
-            UINFO(9,"symTableNextId under NULL"<<endl);
+        } else {
+            UINFO(9, "symTableNextId under NULL" << endl);
             m_symTableNextId = NULL;
         }
     }
-    void reinsert(AstNode* nodep, VSymEnt* parentp=NULL) {
+    void reinsert(AstNode* nodep, VSymEnt* parentp = NULL) {
         reinsert(nodep, parentp, nodep->name());
     }
     void reinsert(AstNode* nodep, VSymEnt* parentp, string name) {
@@ -95,7 +94,8 @@ public:
     void pushNew(AstNode* nodep) { pushNewUnder(nodep, NULL); }
     void pushNewUnder(AstNode* nodep, VSymEnt* parentp) {
         if (!parentp) parentp = symCurrentp();
-        VSymEnt* symp = findNewTable(nodep);  // Will set user4p, which is how we connect table to node
+        VSymEnt* symp
+            = findNewTable(nodep);  // Will set user4p, which is how we connect table to node
         symp->fallbackp(parentp);
         reinsert(nodep, parentp);
         pushScope(symp);
@@ -106,9 +106,13 @@ public:
     }
     void popScope(AstNode* nodep) {
         if (symCurrentp()->nodep() != nodep) {
-            if (debug()) { showUpward(); dump(cout, "-mism: "); }
-            nodep->v3fatalSrc("Symbols suggest ending "<<symCurrentp()->nodep()->prettyTypeName()
-                              <<" but parser thinks ending "<<nodep->prettyTypeName());
+            if (debug()) {
+                showUpward();
+                dump(cout, "-mism: ");
+            }
+            nodep->v3fatalSrc("Symbols suggest ending " << symCurrentp()->nodep()->prettyTypeName()
+                                                        << " but parser thinks ending "
+                                                        << nodep->prettyTypeName());
             return;
         }
         m_sympStack.pop_back();
@@ -116,21 +120,23 @@ public:
         m_symCurrentp = m_sympStack.back();
     }
     void showUpward() {
-        UINFO(1,"ParseSym Stack:\n");
-        for (SymStack::reverse_iterator it=m_sympStack.rbegin(); it!=m_sympStack.rend(); ++it) {
+        UINFO(1, "ParseSym Stack:\n");
+        for (SymStack::reverse_iterator it = m_sympStack.rbegin(); it != m_sympStack.rend();
+             ++it) {
             VSymEnt* symp = *it;
-            UINFO(1,"    "<<symp->nodep()<<endl);
+            UINFO(1, "    " << symp->nodep() << endl);
         }
-        UINFO(1,"ParseSym Current: "<<symCurrentp()->nodep()<<endl);
-    }
-    void dump(std::ostream& os, const string& indent="") {
-        m_syms.dump(os, indent);
+        UINFO(1, "ParseSym Current: " << symCurrentp()->nodep() << endl);
     }
+    void dump(std::ostream& os, const string& indent = "") { m_syms.dump(os, indent); }
     AstNode* findEntUpward(const string& name) {
         // Lookup the given string as an identifier, return type of the id, scanning upward
         VSymEnt* foundp = symCurrentp()->findIdFallback(name);
-        if (foundp) return foundp->nodep();
-        else return NULL;
+        if (foundp) {
+            return foundp->nodep();
+        } else {
+            return NULL;
+        }
     }
     void importItem(AstNode* packagep, const string& id_or_star) {
         // Import from package::id_or_star to this
