@@ -34,6 +34,7 @@ class V3PreProcImp;
 
 // Token codes
 // If changing, see V3PreProc.cpp's V3PreProcImp::tokenName()
+// clang-format off
 #define VP_EOF          0     // Must be zero, a.k.a. YY_NULL, a.k.a. yy_terminate();
 #define VP_EOF_ERROR    400
 
@@ -65,10 +66,13 @@ class V3PreProcImp;
 #define VP_JOIN         314
 
 #define VP_PSL          350
+// clang-format on
 
 //======================================================================
 // Externs created by flex
 // We add a prefix so that other lexers/flexers in the same program won't collide.
+
+// clang-format off
 #ifndef yy_create_buffer
 # define yy_create_buffer V3PreLex_create_buffer
 # define yy_delete_buffer V3PreLex_delete_buffer
@@ -97,9 +101,10 @@ class V3PreProcImp;
 
 #ifndef YY_BUFFER_STATE
 struct yy_buffer_state;
-typedef struct yy_buffer_state *YY_BUFFER_STATE;
+typedef struct yy_buffer_state* YY_BUFFER_STATE;
 # define YY_BUF_SIZE 16384
 #endif
+// clang-format on
 
 extern int yylex();
 extern void yyrestart(FILE*);
@@ -109,7 +114,7 @@ extern char* yyourtext();
 extern size_t yyourleng();
 extern void yyourtext(const char* textp, size_t size);  // Must call with static
 
-YY_BUFFER_STATE yy_create_buffer(FILE *file, int size);
+YY_BUFFER_STATE yy_create_buffer(FILE* file, int size);
 void yy_switch_to_buffer(YY_BUFFER_STATE new_buffer);
 void yy_delete_buffer(YY_BUFFER_STATE b);
 
@@ -123,22 +128,24 @@ void yy_delete_buffer(YY_BUFFER_STATE b);
 
 class VPreStream {
 public:
-    FileLine*           m_curFilelinep; // Current processing point (see also m_tokFilelinep)
-    V3PreLex*           m_lexp;         // Lexer, for resource tracking
-    std::deque<string>  m_buffers;      // Buffer of characters to process
-    int                 m_ignNewlines;  // Ignore multiline newlines
-    bool                m_eof;          // "EOF" buffer
-    bool                m_file;         // Buffer is start of new file
-    int                 m_termState;    // Termination fsm
+    FileLine* m_curFilelinep;  // Current processing point (see also m_tokFilelinep)
+    V3PreLex* m_lexp;  // Lexer, for resource tracking
+    std::deque<string> m_buffers;  // Buffer of characters to process
+    int m_ignNewlines;  // Ignore multiline newlines
+    bool m_eof;  // "EOF" buffer
+    bool m_file;  // Buffer is start of new file
+    int m_termState;  // Termination fsm
     VPreStream(FileLine* fl, V3PreLex* lexp)
-        : m_curFilelinep(fl), m_lexp(lexp),
-          m_ignNewlines(0),
-          m_eof(false), m_file(false), m_termState(0) {
+        : m_curFilelinep(fl)
+        , m_lexp(lexp)
+        , m_ignNewlines(0)
+        , m_eof(false)
+        , m_file(false)
+        , m_termState(0) {
         lexStreamDepthAdd(1);
     }
-    ~VPreStream() {
-        lexStreamDepthAdd(-1);
-    }
+    ~VPreStream() { lexStreamDepthAdd(-1); }
+
 private:
     void lexStreamDepthAdd(int delta);
 };
@@ -147,26 +154,26 @@ private:
 // Class entry for each per-lexer state
 
 class V3PreLex {
-  public:  // Used only by V3PreLex.cpp and V3PreProc.cpp
-    V3PreProcImp*       m_preimpp;      // Preprocessor lexor belongs to
+public:  // Used only by V3PreLex.cpp and V3PreProc.cpp
+    V3PreProcImp* m_preimpp;  // Preprocessor lexor belongs to
     std::stack<VPreStream*> m_streampStack;  // Stack of processing files
-    int                 m_streamDepth;  // Depth of stream processing
-    YY_BUFFER_STATE     m_bufferState;  // Flex state
-    FileLine*           m_tokFilelinep; // Starting position of current token
+    int m_streamDepth;  // Depth of stream processing
+    YY_BUFFER_STATE m_bufferState;  // Flex state
+    FileLine* m_tokFilelinep;  // Starting position of current token
 
     // State to lexer
-    static V3PreLex* s_currentLexp;     ///< Current lexing point
-    int         m_keepComments;         ///< Emit comments in output text
-    int         m_keepWhitespace;       ///< Emit all whitespace in output text
-    bool        m_pedantic;             ///< Obey standard; don't Substitute `error
+    static V3PreLex* s_currentLexp;  ///< Current lexing point
+    int m_keepComments;  ///< Emit comments in output text
+    int m_keepWhitespace;  ///< Emit all whitespace in output text
+    bool m_pedantic;  ///< Obey standard; don't Substitute `error
 
     // State from lexer
-    int         m_formalLevel;  // Parenthesis counting inside def formals
-    int         m_parenLevel;   // Parenthesis counting inside def args
-    bool        m_defCmtSlash;  // /*...*/ comment in define had \ ending
-    bool        m_defQuote;     // Definition value inside quote
-    string      m_defValue;     // Definition value being built.
-    int         m_enterExit;    // For VL_LINE, the enter/exit level
+    int m_formalLevel;  // Parenthesis counting inside def formals
+    int m_parenLevel;  // Parenthesis counting inside def args
+    bool m_defCmtSlash;  // /*...*/ comment in define had \ ending
+    bool m_defQuote;  // Definition value inside quote
+    string m_defValue;  // Definition value being built.
+    int m_enterExit;  // For VL_LINE, the enter/exit level
 
     // CONSTRUCTORS
     V3PreLex(V3PreProcImp* preimpp, FileLine* filelinep) {
@@ -184,7 +191,10 @@ class V3PreLex {
         initFirstBuffer(filelinep);
     }
     ~V3PreLex() {
-        while (!m_streampStack.empty()) { delete m_streampStack.top(); m_streampStack.pop(); }
+        while (!m_streampStack.empty()) {
+            delete m_streampStack.top();
+            m_streampStack.pop();
+        }
         VL_DO_CLEAR(yy_delete_buffer(m_bufferState), m_bufferState = NULL);
     }
 
@@ -213,8 +223,8 @@ class V3PreLex {
     size_t inputToLex(char* buf, size_t max_size);
     /// Called by V3PreProc.cpp to get data from lexer
     YY_BUFFER_STATE currentBuffer();
-    int  lex();
-    int  currentStartState() const;
+    int lex();
+    int currentStartState() const;
     void dumpSummary();
     void dumpStack();
     void unused();
