@@ -97,18 +97,19 @@
 // Support classes
 
 class SplitNodeVertex : public V3GraphVertex {
-    AstNode*    m_nodep;
+    AstNode* m_nodep;
+
 protected:
     SplitNodeVertex(V3Graph* graphp, AstNode* nodep)
-        : V3GraphVertex(graphp), m_nodep(nodep) {}
+        : V3GraphVertex(graphp)
+        , m_nodep(nodep) {}
     virtual ~SplitNodeVertex() {}
     // ACCESSORS
     // Do not make accessor for nodep(),  It may change due to
     // reordering a lower block, but we don't repair it
-    virtual string name() const {
-        return cvtToHex(m_nodep) + ' ' + m_nodep->prettyTypeName();
-    }
+    virtual string name() const { return cvtToHex(m_nodep) + ' ' + m_nodep->prettyTypeName(); }
     virtual FileLine* fileline() const { return nodep()->fileline(); }
+
 public:
     virtual AstNode* nodep() const { return m_nodep; }
 };
@@ -143,7 +144,7 @@ public:
     SplitVarPostVertex(V3Graph* graphp, AstNode* nodep)
         : SplitNodeVertex(graphp, nodep) {}
     virtual ~SplitVarPostVertex() {}
-    virtual string name() const { return string("POST ")+SplitNodeVertex::name(); }
+    virtual string name() const { return string("POST ") + SplitNodeVertex::name(); }
     virtual string dotColor() const { return "CadetBlue"; }
 };
 
@@ -155,11 +156,12 @@ class SplitEdge : public V3GraphEdge {
     static uint32_t s_stepNum;  // Global step number
 protected:
     enum { WEIGHT_NORMAL = 10 };
-    SplitEdge(V3Graph* graphp, V3GraphVertex* fromp, V3GraphVertex* top,
-                int weight, bool cutable=CUTABLE)
+    SplitEdge(V3Graph* graphp, V3GraphVertex* fromp, V3GraphVertex* top, int weight,
+              bool cutable = CUTABLE)
         : V3GraphEdge(graphp, fromp, top, weight, cutable)
         , m_ignoreInStep(0) {}
     virtual ~SplitEdge() {}
+
 public:
     // Iterator for graph functions
     static void incrementStep() { ++s_stepNum; }
@@ -181,7 +183,7 @@ public:
         return ignoreThisStep() ? "dotted" : V3GraphEdge::dotStyle();
     }
 };
-uint32_t        SplitEdge::s_stepNum = 0;
+uint32_t SplitEdge::s_stepNum = 0;
 
 class SplitPostEdge : public SplitEdge {
 public:
@@ -240,28 +242,26 @@ private:
     // AstVarScope::user2p      -> Var SplitNodeVertex* for delayed assignment var, 0=not set yet
     // Ast*::user3p             -> Statement SplitLogicVertex* (temporary only)
     // Ast*::user4              -> Current ordering number (reorderBlock usage)
-    AstUser1InUse       m_inuser1;
-    AstUser2InUse       m_inuser2;
-    AstUser3InUse       m_inuser3;
-    AstUser4InUse       m_inuser4;
+    AstUser1InUse m_inuser1;
+    AstUser2InUse m_inuser2;
+    AstUser3InUse m_inuser3;
+    AstUser4InUse m_inuser4;
 
 protected:
     // TYPES
     typedef std::vector<SplitLogicVertex*> VStack;
 
     // STATE
-    string              m_noReorderWhy;  // Reason we can't reorder
-    VStack              m_stmtStackps;  // Current statements being tracked
-    SplitPliVertex*     m_pliVertexp;   // Element specifying PLI ordering
-    V3Graph             m_graph;        // Scoreboard of var usages/dependencies
-    bool                m_inDly;        // Inside ASSIGNDLY
-    VDouble0            m_statSplits;   // Statistic tracking
+    string m_noReorderWhy;  // Reason we can't reorder
+    VStack m_stmtStackps;  // Current statements being tracked
+    SplitPliVertex* m_pliVertexp;  // Element specifying PLI ordering
+    V3Graph m_graph;  // Scoreboard of var usages/dependencies
+    bool m_inDly;  // Inside ASSIGNDLY
+    VDouble0 m_statSplits;  // Statistic tracking
 
     // CONSTRUCTORS
 public:
-    SplitReorderBaseVisitor() {
-        scoreboardClear();
-    }
+    SplitReorderBaseVisitor() { scoreboardClear(); }
     virtual ~SplitReorderBaseVisitor() {
         V3Stats::addStat("Optimizations, Split always", m_statSplits);
     }
@@ -271,7 +271,7 @@ protected:
     VL_DEBUG_FUNC;  // Declare debug()
 
     void scoreboardClear() {
-        //VV*****  We reset user1p() and user2p on each block!!!
+        // VV*****  We reset user1p() and user2p on each block!!!
         m_inDly = false;
         m_graph.clear();
         m_stmtStackps.clear();
@@ -298,14 +298,14 @@ private:
         }
     }
     void scoreboardPushStmt(AstNode* nodep) {
-        //UINFO(9,"    push "<<nodep<<endl);
+        // UINFO(9, "    push " << nodep << endl);
         SplitLogicVertex* vertexp = new SplitLogicVertex(&m_graph, nodep);
         m_stmtStackps.push_back(vertexp);
         UASSERT_OBJ(!nodep->user3p(), nodep, "user3p should not be used; cleared in processBlock");
         nodep->user3p(vertexp);
     }
     void scoreboardPopStmt() {
-        //UINFO(9,"    pop"<<endl);
+        // UINFO(9, "    pop" << endl);
         if (m_stmtStackps.empty()) v3fatalSrc("Stack underflow");
         m_stmtStackps.pop_back();
     }
@@ -313,7 +313,7 @@ private:
 protected:
     void scanBlock(AstNode* nodep) {
         // Iterate across current block, making the scoreboard
-        for (AstNode* nextp=nodep; nextp; nextp=nextp->nextp()) {
+        for (AstNode* nextp = nodep; nextp; nextp = nextp->nextp()) {
             scoreboardPushStmt(nextp);
             iterate(nextp);
             scoreboardPopStmt();
@@ -321,17 +321,15 @@ protected:
     }
 
     void pruneDepsOnInputs() {
-        for (V3GraphVertex* vertexp = m_graph.verticesBeginp();
-             vertexp; vertexp=vertexp->verticesNextp()) {
-            if (!vertexp->outBeginp()
-                && dynamic_cast<SplitVarStdVertex*>(vertexp)) {
+        for (V3GraphVertex* vertexp = m_graph.verticesBeginp(); vertexp;
+             vertexp = vertexp->verticesNextp()) {
+            if (!vertexp->outBeginp() && dynamic_cast<SplitVarStdVertex*>(vertexp)) {
                 if (debug() >= 9) {
                     SplitVarStdVertex* stdp = static_cast<SplitVarStdVertex*>(vertexp);
-                    UINFO(0, "Will prune deps on var "<<stdp->nodep()<<endl);
+                    UINFO(0, "Will prune deps on var " << stdp->nodep() << endl);
                     stdp->nodep()->dumpTree(cout, "- ");
                 }
-                for (V3GraphEdge* edgep = vertexp->inBeginp();
-                     edgep; edgep=edgep->inNextp()) {
+                for (V3GraphEdge* edgep = vertexp->inBeginp(); edgep; edgep = edgep->inNextp()) {
                     SplitEdge* oedgep = dynamic_cast<SplitEdge*>(edgep);
                     oedgep->setIgnoreThisStep();
                 }
@@ -350,7 +348,7 @@ protected:
 
     virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         m_inDly = true;
-        UINFO(4,"    ASSIGNDLY "<<nodep<<endl);
+        UINFO(4, "    ASSIGNDLY " << nodep << endl);
         iterateChildren(nodep);
         m_inDly = false;
     }
@@ -386,7 +384,7 @@ protected:
 
                 // SPEEDUP: We add duplicate edges, that should be fixed
                 if (m_inDly && nodep->lvalue()) {
-                    UINFO(4,"     VARREFDLY: "<<nodep<<endl);
+                    UINFO(4, "     VARREFDLY: " << nodep << endl);
                     // Delayed variable is different from non-delayed variable
                     if (!vscp->user2p()) {
                         SplitVarPostVertex* vpostp = new SplitVarPostVertex(&m_graph, vscp);
@@ -396,21 +394,21 @@ protected:
                     SplitVarPostVertex* vpostp
                         = reinterpret_cast<SplitVarPostVertex*>(vscp->user2p());
                     // Add edges
-                    for (VStack::iterator it = m_stmtStackps.begin();
-                         it != m_stmtStackps.end(); ++it) {
+                    for (VStack::iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end();
+                         ++it) {
                         new SplitLVEdge(&m_graph, vpostp, *it);
                     }
                 } else {  // Nondelayed assignment
                     if (nodep->lvalue()) {
                         // Non-delay; need to maintain existing ordering
                         // with all consumers of the signal
-                        UINFO(4,"     VARREFLV: "<<nodep<<endl);
+                        UINFO(4, "     VARREFLV: " << nodep << endl);
                         for (VStack::iterator it = m_stmtStackps.begin();
                              it != m_stmtStackps.end(); ++it) {
                             new SplitLVEdge(&m_graph, vstdp, *it);
                         }
                     } else {
-                        UINFO(4,"     VARREF:   "<<nodep<<endl);
+                        UINFO(4, "     VARREF:   " << nodep << endl);
                         makeRvalueEdges(vstdp);
                     }
                 }
@@ -423,7 +421,7 @@ protected:
         // This is overly pessimistic; we could treat jumps as barriers, and
         // reorder everything between jumps/labels, however jumps are rare
         // in always, so the performance gain probably isn't worth the work.
-        UINFO(9,"         NoReordering "<<nodep<<endl);
+        UINFO(9, "         NoReordering " << nodep << endl);
         m_noReorderWhy = "JumpGo";
         iterateChildren(nodep);
     }
@@ -433,7 +431,7 @@ protected:
     virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // **** SPECIAL default type that sets PLI_ORDERING
         if (!m_stmtStackps.empty() && !nodep->isPure()) {
-            UINFO(9,"         NotSplittable "<<nodep<<endl);
+            UINFO(9, "         NotSplittable " << nodep << endl);
             scoreboardPli(nodep);
         }
         iterateChildren(nodep);
@@ -446,9 +444,7 @@ private:
 class ReorderVisitor : public SplitReorderBaseVisitor {
     // CONSTRUCTORS
 public:
-    explicit ReorderVisitor(AstNetlist* nodep) {
-        iterate(nodep);
-    }
+    explicit ReorderVisitor(AstNetlist* nodep) { iterate(nodep); }
     virtual ~ReorderVisitor() {}
 
     // METHODS
@@ -461,18 +457,18 @@ protected:
 
     void cleanupBlockGraph(AstNode* nodep) {
         // Transform the graph into what we need
-        UINFO(5, "ReorderBlock "<<nodep<<endl);
+        UINFO(5, "ReorderBlock " << nodep << endl);
         m_graph.removeRedundantEdges(&V3GraphEdge::followAlwaysTrue);
 
-        if (debug()>=9) {
+        if (debug() >= 9) {
             m_graph.dumpDotFilePrefixed("reorderg_nodup", false);
-            //m_graph.dump(); cout<<endl;
+            // m_graph.dump(); cout<<endl;
         }
 
         // Mark all the logic for this step
         // Vertex::m_user begin: true indicates logic for this step
         m_graph.userClearVertices();
-        for (AstNode* nextp=nodep; nextp; nextp=nextp->nextp()) {
+        for (AstNode* nextp = nodep; nextp; nextp = nextp->nextp()) {
             SplitLogicVertex* vvertexp = reinterpret_cast<SplitLogicVertex*>(nextp->user3p());
             vvertexp->user(true);
         }
@@ -484,16 +480,17 @@ protected:
 
         // For reordering this single block only, mark all logic
         // vertexes not involved with this step as unimportant
-        for (V3GraphVertex* vertexp = m_graph.verticesBeginp();
-             vertexp; vertexp=vertexp->verticesNextp()) {
+        for (V3GraphVertex* vertexp = m_graph.verticesBeginp(); vertexp;
+             vertexp = vertexp->verticesNextp()) {
             if (SplitLogicVertex* vvertexp = dynamic_cast<SplitLogicVertex*>(vertexp)) {
                 if (!vvertexp->user()) {
-                    for (V3GraphEdge* edgep = vertexp->inBeginp(); edgep; edgep=edgep->inNextp()) {
+                    for (V3GraphEdge* edgep = vertexp->inBeginp(); edgep;
+                         edgep = edgep->inNextp()) {
                         SplitEdge* oedgep = dynamic_cast<SplitEdge*>(edgep);
                         oedgep->setIgnoreThisStep();
                     }
-                    for (V3GraphEdge* edgep = vertexp->outBeginp();
-                         edgep; edgep=edgep->outNextp()) {
+                    for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep;
+                         edgep = edgep->outNextp()) {
                         SplitEdge* oedgep = dynamic_cast<SplitEdge*>(edgep);
                         oedgep->setIgnoreThisStep();
                     }
@@ -507,7 +504,7 @@ protected:
 
         // Add hard orderings between all nodes of same color, in the order they appeared
         vl_unordered_map<uint32_t, SplitLogicVertex*> lastOfColor;
-        for (AstNode* nextp=nodep; nextp; nextp=nextp->nextp()) {
+        for (AstNode* nextp = nodep; nextp; nextp = nextp->nextp()) {
             SplitLogicVertex* vvertexp = reinterpret_cast<SplitLogicVertex*>(nextp->user3p());
             uint32_t color = vvertexp->color();
             UASSERT_OBJ(color, nextp, "No node color assigned");
@@ -520,20 +517,20 @@ protected:
         // And a real ordering to get the statements into something reasonable
         // We don't care if there's cutable violations here...
         // Non-cutable violations should be impossible; as those edges are program-order
-        if (debug()>=9) m_graph.dumpDotFilePrefixed(string("splitg_preo"), false);
+        if (debug() >= 9) m_graph.dumpDotFilePrefixed(string("splitg_preo"), false);
         m_graph.acyclic(&SplitEdge::followCyclic);
         m_graph.rank(&SplitEdge::followCyclic);  // Or order(), but that's more expensive
-        if (debug()>=9) m_graph.dumpDotFilePrefixed(string("splitg_opt"), false);
+        if (debug() >= 9) m_graph.dumpDotFilePrefixed(string("splitg_opt"), false);
     }
 
     void reorderBlock(AstNode* nodep) {
         // Reorder statements in the completed graph
 
         // Map the rank numbers into nodes they associate with
-        typedef std::multimap<uint32_t,AstNode*> RankNodeMap;
+        typedef std::multimap<uint32_t, AstNode*> RankNodeMap;
         RankNodeMap rankMap;
         int currOrder = 0;  // Existing sequence number of assignment
-        for (AstNode* nextp=nodep; nextp; nextp=nextp->nextp()) {
+        for (AstNode* nextp = nodep; nextp; nextp = nextp->nextp()) {
             SplitLogicVertex* vvertexp = reinterpret_cast<SplitLogicVertex*>(nextp->user3p());
             rankMap.insert(make_pair(vvertexp->rank(), nextp));
             nextp->user4(++currOrder);  // Record current ordering
@@ -542,23 +539,28 @@ protected:
         // Is the current ordering OK?
         bool leaveAlone = true;
         int newOrder = 0;  // New sequence number of assignment
-        for (RankNodeMap::const_iterator it = rankMap.begin();
-             it != rankMap.end(); ++it) {
+        for (RankNodeMap::const_iterator it = rankMap.begin(); it != rankMap.end(); ++it) {
             AstNode* nextp = it->second;
             if (++newOrder != nextp->user4()) leaveAlone = false;
         }
         if (leaveAlone) {
-            UINFO(6,"   No changes\n");
+            UINFO(6, "   No changes\n");
         } else {
             AstNRelinker replaceHandle;  // Where to add the list
             AstNode* newListp = NULL;
             for (RankNodeMap::const_iterator it = rankMap.begin(); it != rankMap.end(); ++it) {
                 AstNode* nextp = it->second;
-                UINFO(6, "   New order: "<<nextp<<endl);
-                if (nextp == nodep) nodep->unlinkFrBack(&replaceHandle);
-                else nextp->unlinkFrBack();
-                if (newListp) newListp = newListp->addNext(nextp);
-                else newListp = nextp;
+                UINFO(6, "   New order: " << nextp << endl);
+                if (nextp == nodep) {
+                    nodep->unlinkFrBack(&replaceHandle);
+                } else {
+                    nextp->unlinkFrBack();
+                }
+                if (newListp) {
+                    newListp = newListp->addNext(nextp);
+                } else {
+                    newListp = nextp;
+                }
             }
             replaceHandle.relink(newListp);
         }
@@ -579,19 +581,19 @@ protected:
             // Just one, so can't reorder.  Just look for more blocks/statements.
             iterate(nodep);
         } else {
-            UINFO(9,"  processBlock "<<nodep<<endl);
+            UINFO(9, "  processBlock " << nodep << endl);
             // Process block and followers
             scanBlock(nodep);
             if (m_noReorderWhy != "") {  // Jump or something nasty
-                UINFO(9,"  NoReorderBlock because "<<m_noReorderWhy<<endl);
+                UINFO(9, "  NoReorderBlock because " << m_noReorderWhy << endl);
             } else {
                 // Reorder statements in this block
                 cleanupBlockGraph(nodep);
                 reorderBlock(nodep);
                 // Delete old vertexes and edges only applying to this block
                 // First, walk back to first in list
-                while (firstp->backp()->nextp()==firstp) firstp = firstp->backp();
-                for (AstNode* nextp=firstp; nextp; nextp=nextp->nextp()) {
+                while (firstp->backp()->nextp() == firstp) firstp = firstp->backp();
+                for (AstNode* nextp = firstp; nextp; nextp = nextp->nextp()) {
                     SplitLogicVertex* vvertexp
                         = reinterpret_cast<SplitLogicVertex*>(nextp->user3p());
                     vvertexp->unlinkDelete(&m_graph);
@@ -603,19 +605,20 @@ protected:
     }
 
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
-        UINFO(4,"   ALW   "<<nodep<<endl);
-        if (debug()>=9) nodep->dumpTree(cout, "   alwIn:: ");
+        UINFO(4, "   ALW   " << nodep << endl);
+        if (debug() >= 9) nodep->dumpTree(cout, "   alwIn:: ");
         scoreboardClear();
         processBlock(nodep->bodysp());
-        if (debug()>=9) nodep->dumpTree(cout, "   alwOut: ");
+        if (debug() >= 9) nodep->dumpTree(cout, "   alwOut: ");
     }
 
     virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
-        UINFO(4,"     IF "<<nodep<<endl);
+        UINFO(4, "     IF " << nodep << endl);
         iterateAndNextNull(nodep->condp());
         processBlock(nodep->ifsp());
         processBlock(nodep->elsesp());
     }
+
 private:
     VL_UNCOPYABLE(ReorderVisitor);
 };
@@ -638,9 +641,7 @@ class IfColorVisitor : public AstNVisitor {
 public:
     // Visit through *nodep and map each AstNodeIf within to the set of
     // colors it will participate in. Also find the whole set of colors.
-    explicit IfColorVisitor(AstAlways* nodep) {
-        iterate(nodep);
-    }
+    explicit IfColorVisitor(AstAlways* nodep) { iterate(nodep); }
     virtual ~IfColorVisitor() {}
 
     // METHODS
@@ -660,8 +661,7 @@ private:
             UINFO(8, "  SVL " << vertexp << " has color " << color << "\n");
 
             // Record that all containing ifs have this color.
-            for (IfStack::const_iterator it = m_ifStack.begin();
-                 it != m_ifStack.end(); ++it) {
+            for (IfStack::const_iterator it = m_ifStack.begin(); it != m_ifStack.end(); ++it) {
                 m_ifColors[*it].insert(color);
             }
         }
@@ -700,9 +700,7 @@ public:
     // EmitSplitVisitor visits through always block *nodep
     // and generates its split blocks, writing the split blocks
     // into *newBlocksp.
-    EmitSplitVisitor(AstAlways* nodep,
-                     const IfColorVisitor* ifColorp,
-                     AlwaysVec* newBlocksp)
+    EmitSplitVisitor(AstAlways* nodep, const IfColorVisitor* ifColorp, AlwaysVec* newBlocksp)
         : m_origAlwaysp(nodep)
         , m_ifColorp(ifColorp)
         , m_newBlocksp(newBlocksp) {
@@ -715,13 +713,11 @@ public:
     void go() {
         // Create a new always for each color
         const ColorSet& colors = m_ifColorp->colors();
-        for (ColorSet::const_iterator color = colors.begin();
-             color != colors.end(); ++color) {
+        for (ColorSet::const_iterator color = colors.begin(); color != colors.end(); ++color) {
             // We don't need to clone m_origAlwaysp->sensesp() here;
             // V3Activate already moved it to a parent node.
-            AstAlways* alwaysp =
-                new AstAlways(m_origAlwaysp->fileline(), VAlwaysKwd::ALWAYS,
-                              NULL, NULL);
+            AstAlways* alwaysp
+                = new AstAlways(m_origAlwaysp->fileline(), VAlwaysKwd::ALWAYS, NULL, NULL);
             // Put a placeholder node into stmtp to track our position.
             // We'll strip these out after the blocks are fully cloned.
             AstSplitPlaceholder* placeholderp = makePlaceholderp();
@@ -769,16 +765,12 @@ protected:
         typedef vl_unordered_map<uint32_t, AstNodeIf*> CloneMap;
         CloneMap clones;
 
-        for (ColorSet::const_iterator color = colors.begin();
-             color != colors.end(); ++color) {
+        for (ColorSet::const_iterator color = colors.begin(); color != colors.end(); ++color) {
             // Clone this if into its set of split blocks
             AstSplitPlaceholder* if_placeholderp = makePlaceholderp();
             AstSplitPlaceholder* else_placeholderp = makePlaceholderp();
-            AstIf* clonep =
-                new AstIf(nodep->fileline(),
-                          nodep->condp()->cloneTree(true),
-                          if_placeholderp,
-                          else_placeholderp);
+            AstIf* clonep = new AstIf(nodep->fileline(), nodep->condp()->cloneTree(true),
+                                      if_placeholderp, else_placeholderp);
             AstIf* origp = VN_CAST(nodep, If);
             if (origp) {
                 // Preserve pragmas from unique if's
@@ -794,15 +786,13 @@ protected:
 
         iterateAndNextNull(nodep->ifsp());
 
-        for (ColorSet::const_iterator color = colors.begin();
-             color != colors.end(); ++color) {
+        for (ColorSet::const_iterator color = colors.begin(); color != colors.end(); ++color) {
             m_addAfter[*color] = clones[*color]->elsesp();
         }
 
         iterateAndNextNull(nodep->elsesp());
 
-        for (ColorSet::const_iterator color = colors.begin();
-             color != colors.end(); ++color) {
+        for (ColorSet::const_iterator color = colors.begin(); color != colors.end(); ++color) {
             m_addAfter[*color] = clones[*color];
         }
     }
@@ -817,17 +807,14 @@ class RemovePlaceholdersVisitor : public AstNVisitor {
 public:
     explicit RemovePlaceholdersVisitor(AstNode* nodep) {
         iterate(nodep);
-        for (NodeSet::const_iterator it = m_removeSet.begin();
-             it != m_removeSet.end(); ++it) {
+        for (NodeSet::const_iterator it = m_removeSet.begin(); it != m_removeSet.end(); ++it) {
             AstNode* np = *it;
             np->unlinkFrBack();  // Without next
             VL_DO_DANGLING(np->deleteTree(), np);
         }
     }
     virtual ~RemovePlaceholdersVisitor() {}
-    virtual void visit(AstSplitPlaceholder* nodep) VL_OVERRIDE {
-        m_removeSet.insert(nodep);
-    }
+    virtual void visit(AstSplitPlaceholder* nodep) VL_OVERRIDE { m_removeSet.insert(nodep); }
     virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 private:
@@ -854,11 +841,11 @@ public:
         // Splice newly-split blocks into the tree. Remove placeholders
         // from newly-split blocks. Delete the original always blocks
         // that we're replacing.
-        for (ReplaceMap::iterator it = m_replaceBlocks.begin();
-             it != m_replaceBlocks.end(); ++it) {
+        for (ReplaceMap::iterator it = m_replaceBlocks.begin(); it != m_replaceBlocks.end();
+             ++it) {
             AstAlways* origp = it->first;
-            for (AlwaysVec::iterator addme = it->second.begin();
-                 addme != it->second.end(); ++addme) {
+            for (AlwaysVec::iterator addme = it->second.begin(); addme != it->second.end();
+                 ++addme) {
                 origp->addNextHere(*addme);
                 RemovePlaceholdersVisitor removePlaceholders(*addme);
             }
@@ -876,9 +863,7 @@ protected:
         // not rvalues in the if/else bodies.
         for (VStack::const_iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end(); ++it) {
             AstNodeIf* ifNodep = VN_CAST((*it)->nodep(), NodeIf);
-            if (ifNodep && (m_curIfConditional != ifNodep)) {
-                continue;
-            }
+            if (ifNodep && (m_curIfConditional != ifNodep)) continue;
             new SplitRVEdge(&m_graph, *it, vstdp);
         }
     }
@@ -899,8 +884,8 @@ protected:
         // For any 'if' node whose deps have all been pruned
         // (meaning, its conditional expression only looks at primary
         // inputs) prune all edges that depend on the 'if'.
-        for (V3GraphVertex* vertexp = m_graph.verticesBeginp();
-             vertexp; vertexp=vertexp->verticesNextp()) {
+        for (V3GraphVertex* vertexp = m_graph.verticesBeginp(); vertexp;
+             vertexp = vertexp->verticesNextp()) {
             SplitLogicVertex* logicp = dynamic_cast<SplitLogicVertex*>(vertexp);
             if (!logicp) continue;
 
@@ -908,8 +893,7 @@ protected:
             if (!ifNodep) continue;
 
             bool pruneMe = true;
-            for (V3GraphEdge* edgep = logicp->outBeginp();
-                 edgep; edgep = edgep->outNextp()) {
+            for (V3GraphEdge* edgep = logicp->outBeginp(); edgep; edgep = edgep->outNextp()) {
                 SplitEdge* oedgep = dynamic_cast<SplitEdge*>(edgep);
                 if (!oedgep->ignoreThisStep()) {
                     // This if conditional depends on something we can't
@@ -921,8 +905,8 @@ protected:
                     if (debug() >= 9) {
                         V3GraphVertex* vxp = oedgep->top();
                         SplitNodeVertex* nvxp = dynamic_cast<SplitNodeVertex*>(vxp);
-                        UINFO(0, "Cannot prune if-node due to edge "<<oedgep<<
-                              " pointing to node "<<nvxp->nodep()<<endl);
+                        UINFO(0, "Cannot prune if-node due to edge "
+                                     << oedgep << " pointing to node " << nvxp->nodep() << endl);
                         nvxp->nodep()->dumpTree(cout, "- ");
                     }
 
@@ -933,21 +917,20 @@ protected:
             if (!pruneMe) continue;
 
             // This if can be split; prune dependencies on it.
-            for (V3GraphEdge* edgep = logicp->inBeginp();
-                 edgep; edgep = edgep->inNextp()) {
+            for (V3GraphEdge* edgep = logicp->inBeginp(); edgep; edgep = edgep->inNextp()) {
                 SplitEdge* oedgep = dynamic_cast<SplitEdge*>(edgep);
                 oedgep->setIgnoreThisStep();
             }
         }
 
-        if (debug()>=9) m_graph.dumpDotFilePrefixed("splitg_nodup", false);
+        if (debug() >= 9) m_graph.dumpDotFilePrefixed("splitg_nodup", false);
 
         // Weak coloring to determine what needs to remain grouped
         // in a single always. This follows all edges excluding:
         //  - those we pruned above
         //  - PostEdges, which are done later
         m_graph.weaklyConnected(&SplitEdge::followScoreboard);
-        if (debug()>=9) m_graph.dumpDotFilePrefixed("splitg_colored", false);
+        if (debug() >= 9) m_graph.dumpDotFilePrefixed("splitg_colored", false);
     }
 
     virtual void visit(AstAlways* nodep) VL_OVERRIDE {
@@ -957,13 +940,13 @@ protected:
 
         if (m_noReorderWhy != "") {
             // We saw a jump or something else rare that we don't handle.
-            UINFO(9,"  NoSplitBlock because "<<m_noReorderWhy<<endl);
+            UINFO(9, "  NoSplitBlock because " << m_noReorderWhy << endl);
             return;
         }
 
         // Look across the entire tree of if/else blocks in the always,
         // and color regions that must be kept together.
-        UINFO(5, "SplitVisitor @ "<<nodep<<endl);
+        UINFO(5, "SplitVisitor @ " << nodep << endl);
         colorAlwaysGraph();
 
         // Map each AstNodeIf to the set of colors (split always blocks)
@@ -978,19 +961,19 @@ protected:
 
             // Visit through the original always block one more time,
             // and emit the split always blocks into m_replaceBlocks:
-            EmitSplitVisitor emitSplit(nodep, &ifColor,
-                                       &(m_replaceBlocks[nodep]));
+            EmitSplitVisitor emitSplit(nodep, &ifColor, &(m_replaceBlocks[nodep]));
             emitSplit.go();
         }
     }
     virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
-        UINFO(4,"     IF "<<nodep<<endl);
+        UINFO(4, "     IF " << nodep << endl);
         m_curIfConditional = nodep;
         iterateAndNextNull(nodep->condp());
         m_curIfConditional = NULL;
         scanBlock(nodep->ifsp());
         scanBlock(nodep->elsesp());
     }
+
 private:
     VL_UNCOPYABLE(SplitVisitor);
 };
@@ -999,16 +982,12 @@ private:
 // Split class functions
 
 void V3Split::splitReorderAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        ReorderVisitor visitor(nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { ReorderVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("reorder", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
 void V3Split::splitAlwaysAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
-    {
-        SplitVisitor visitor(nodep);
-    }  // Destruct before checking
+    UINFO(2, __FUNCTION__ << ": " << endl);
+    { SplitVisitor visitor(nodep); }  // Destruct before checking
     V3Global::dumpCheckGlobalTree("split", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
