@@ -36,31 +36,31 @@ class StatsVisitor : public AstNVisitor {
 private:
     // NODE STATE/TYPES
 
-    typedef std::map<string,int> NameMap;  // Number of times a name appears
+    typedef std::map<string, int> NameMap;  // Number of times a name appears
 
     // STATE
-    string      m_stage;                // Name of the stage we are scanning
+    string m_stage;  // Name of the stage we are scanning
     /// m_fast = true:  Counting only critical branch of fastpath
     /// m_fast = false:  Counting every node, ignoring structure of program
-    bool        m_fast;
+    bool m_fast;
 
-    AstCFunc*   m_cfuncp;               // Current CFUNC
-    VDouble0    m_statInstrLong;        // Instruction count
-    bool        m_counting;             // Currently counting
-    double      m_instrs;               // Current instr count (for determining branch direction)
-    bool        m_tracingCall;          // Iterating into a CCall to a CFunc
+    AstCFunc* m_cfuncp;  // Current CFUNC
+    VDouble0 m_statInstrLong;  // Instruction count
+    bool m_counting;  // Currently counting
+    double m_instrs;  // Current instr count (for determining branch direction)
+    bool m_tracingCall;  // Iterating into a CCall to a CFunc
 
-    std::vector<VDouble0> m_statTypeCount;     // Nodes of given type
-    VDouble0           m_statAbove[AstType::_ENUM_END][AstType::_ENUM_END];  // Nodes of given type
-    VDouble0           m_statPred[VBranchPred::_ENUM_END];  // Nodes of given type
-    VDouble0           m_statInstr;            // Instruction count
-    VDouble0           m_statInstrFast;        // Instruction count, non-slow() eval functions only
-    std::vector<VDouble0> m_statVarWidths;     // Variables of given width
-    std::vector<NameMap>  m_statVarWidthNames;  // Var names of given width
-    VDouble0           m_statVarArray;         // Statistic tracking
-    VDouble0           m_statVarBytes;         // Statistic tracking
-    VDouble0           m_statVarClock;         // Statistic tracking
-    VDouble0           m_statVarScpBytes;      // Statistic tracking
+    std::vector<VDouble0> m_statTypeCount;  // Nodes of given type
+    VDouble0 m_statAbove[AstType::_ENUM_END][AstType::_ENUM_END];  // Nodes of given type
+    VDouble0 m_statPred[VBranchPred::_ENUM_END];  // Nodes of given type
+    VDouble0 m_statInstr;  // Instruction count
+    VDouble0 m_statInstrFast;  // Instruction count, non-slow() eval functions only
+    std::vector<VDouble0> m_statVarWidths;  // Variables of given width
+    std::vector<NameMap> m_statVarWidthNames;  // Var names of given width
+    VDouble0 m_statVarArray;  // Statistic tracking
+    VDouble0 m_statVarBytes;  // Statistic tracking
+    VDouble0 m_statVarClock;  // Statistic tracking
+    VDouble0 m_statVarScpBytes;  // Statistic tracking
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
@@ -92,13 +92,16 @@ private:
         iterateChildrenConst(nodep);
         if (m_counting && nodep->dtypep()) {
             if (nodep->isUsedClock()) ++m_statVarClock;
-            if (VN_IS(nodep->dtypeSkipRefp(), UnpackArrayDType)) ++m_statVarArray;
-            else m_statVarBytes += nodep->dtypeSkipRefp()->widthTotalBytes();
-            if (int(m_statVarWidths.size()) <= nodep->width()) {
-                m_statVarWidths.resize(nodep->width()+5);
-                if (v3Global.opt.statsVars()) m_statVarWidthNames.resize(nodep->width()+5);
+            if (VN_IS(nodep->dtypeSkipRefp(), UnpackArrayDType)) {
+                ++m_statVarArray;
+            } else {
+                m_statVarBytes += nodep->dtypeSkipRefp()->widthTotalBytes();
             }
-            ++ m_statVarWidths.at(nodep->width());
+            if (int(m_statVarWidths.size()) <= nodep->width()) {
+                m_statVarWidths.resize(nodep->width() + 5);
+                if (v3Global.opt.statsVars()) m_statVarWidthNames.resize(nodep->width() + 5);
+            }
+            ++m_statVarWidths.at(nodep->width());
             string pn = nodep->prettyName();
             if (v3Global.opt.statsVars()) {
                 NameMap& nameMapr = m_statVarWidthNames.at(nodep->width());
@@ -120,14 +123,12 @@ private:
         }
     }
     virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
-        UINFO(4,"   IF i="<<m_instrs<<" "<<nodep<<endl);
+        UINFO(4, "   IF i=" << m_instrs << " " << nodep << endl);
         allNodes(nodep);
         // Condition is part of cost allocated to PREVIOUS block
         iterateAndNextConstNull(nodep->condp());
         // Track prediction
-        if (m_counting) {
-            ++m_statPred[nodep->branchPred()];
-        }
+        if (m_counting) ++m_statPred[nodep->branchPred()];
         if (!m_fast) {
             // Count everything
             iterateChildrenConst(nodep);
@@ -171,7 +172,7 @@ private:
         }
     }
     // While's we assume evaluate once.
-    //virtual void visit(AstWhile* nodep) VL_OVERRIDE {
+    // virtual void visit(AstWhile* nodep) VL_OVERRIDE {
 
     virtual void visit(AstNodeCCall* nodep) VL_OVERRIDE {
         allNodes(nodep);
@@ -206,11 +207,13 @@ private:
         allNodes(nodep);
         iterateChildrenConst(nodep);
     }
+
 public:
     // CONSTRUCTORS
     StatsVisitor(AstNetlist* nodep, const string& stage, bool fast)
-        : m_stage(stage), m_fast(fast) {
-        UINFO(9,"Starting stats, fast="<<fast<<endl);
+        : m_stage(stage)
+        , m_fast(fast) {
+        UINFO(9, "Starting stats, fast=" << fast << endl);
         m_cfuncp = NULL;
         m_counting = !m_fast;
         m_instrs = 0;
@@ -223,53 +226,55 @@ public:
     virtual ~StatsVisitor() {
         // Done. Publish statistics
         V3Stats::addStat(m_stage, "Instruction count, TOTAL", m_statInstr);
-        V3Stats::addStat(m_stage, "Instruction count, fast critical",  m_statInstrFast);
+        V3Stats::addStat(m_stage, "Instruction count, fast critical", m_statInstrFast);
         // Vars
         V3Stats::addStat(m_stage, "Vars, unpacked arrayed", m_statVarArray);
         V3Stats::addStat(m_stage, "Vars, clock attribute", m_statVarClock);
         V3Stats::addStat(m_stage, "Var space, non-arrays, bytes", m_statVarBytes);
-        if (m_statVarScpBytes!=0.0) {
+        if (m_statVarScpBytes != 0.0) {
             V3Stats::addStat(m_stage, "Var space, scoped, bytes", m_statVarScpBytes);
         }
-        for (unsigned i=0; i<m_statVarWidths.size(); i++) {
+        for (unsigned i = 0; i < m_statVarWidths.size(); i++) {
             double count = double(m_statVarWidths.at(i));
             if (count != 0.0) {
                 if (v3Global.opt.statsVars()) {
                     NameMap& nameMapr = m_statVarWidthNames.at(i);
-                    for (NameMap::iterator it=nameMapr.begin(); it!=nameMapr.end(); ++it) {
-                        std::ostringstream os; os<<"Vars, width "
-                                                 <<std::setw(5)<<std::dec<<i<<" "<<it->first;
+                    for (NameMap::iterator it = nameMapr.begin(); it != nameMapr.end(); ++it) {
+                        std::ostringstream os;
+                        os << "Vars, width " << std::setw(5) << std::dec << i << " " << it->first;
                         V3Stats::addStat(m_stage, os.str(), it->second);
                     }
                 } else {
-                    std::ostringstream os; os<<"Vars, width "<<std::setw(5)<<std::dec<<i;
+                    std::ostringstream os;
+                    os << "Vars, width " << std::setw(5) << std::dec << i;
                     V3Stats::addStat(m_stage, os.str(), count);
                 }
             }
         }
         // Node types
-        for (int type=0; type<AstType::_ENUM_END; type++) {
+        for (int type = 0; type < AstType::_ENUM_END; type++) {
             double count = double(m_statTypeCount.at(type));
             if (count != 0.0) {
-                V3Stats::addStat(m_stage, string("Node count, ")+AstType(type).ascii(), count);
+                V3Stats::addStat(m_stage, string("Node count, ") + AstType(type).ascii(), count);
             }
         }
-        for (int type=0; type < AstType::_ENUM_END; type++) {
-            for (int type2=0; type2 < AstType::_ENUM_END; type2++) {
+        for (int type = 0; type < AstType::_ENUM_END; type++) {
+            for (int type2 = 0; type2 < AstType::_ENUM_END; type2++) {
                 double count = double(m_statAbove[type][type2]);
                 if (count != 0.0) {
-                    V3Stats::addStat(m_stage, (string("Node pairs, ")
-                                               +AstType(type).ascii()+"_"+AstType(type2).ascii()),
+                    V3Stats::addStat(m_stage,
+                                     (string("Node pairs, ") + AstType(type).ascii() + "_"
+                                      + AstType(type2).ascii()),
                                      count);
                 }
             }
         }
         // Branch pred
-        for (int type=0; type < VBranchPred::_ENUM_END; type++) {
+        for (int type = 0; type < VBranchPred::_ENUM_END; type++) {
             double count = double(m_statPred[type]);
             if (count != 0.0) {
-                V3Stats::addStat(m_stage, (string("Branch prediction, ")
-                                           + VBranchPred(type).ascii()), count);
+                V3Stats::addStat(
+                    m_stage, (string("Branch prediction, ") + VBranchPred(type).ascii()), count);
             }
         }
     }
@@ -279,7 +284,7 @@ public:
 // Top Stats class
 
 void V3Stats::statsStageAll(AstNetlist* nodep, const string& stage, bool fast) {
-    StatsVisitor visitor (nodep, stage, fast);
+    StatsVisitor visitor(nodep, stage, fast);
 }
 
 void V3Stats::statsFinalAll(AstNetlist* nodep) {
