@@ -26,6 +26,7 @@
 #include "V3Case.h"
 #include "V3Cast.h"
 #include "V3Changed.h"
+#include "V3Class.h"
 #include "V3Clean.h"
 #include "V3Clock.h"
 #include "V3Combine.h"
@@ -41,6 +42,7 @@
 #include "V3Descope.h"
 #include "V3EmitC.h"
 #include "V3EmitCMake.h"
+#include "V3EmitCMain.h"
 #include "V3EmitMk.h"
 #include "V3EmitV.h"
 #include "V3EmitXml.h"
@@ -143,9 +145,7 @@ static void process() {
 
     // Coverage insertion
     //    Before we do dead code elimination and inlining, or we'll lose it.
-    if (v3Global.opt.coverage()) {
-        V3Coverage::coverage(v3Global.rootp());
-    }
+    if (v3Global.opt.coverage()) V3Coverage::coverage(v3Global.rootp());
 
     // Push constants, but only true constants preserving liveness
     // so V3Undriven sees variables to be eliminated, ie "if (0 && foo) ..."
@@ -161,7 +161,7 @@ static void process() {
     //
     V3Assert::assertAll(v3Global.rootp());
 
-    if (!v3Global.opt.xmlOnly()) {
+    if (!(v3Global.opt.xmlOnly() && !v3Global.opt.flatten())) {
         // Add top level wrapper with instance pointing to old top
         // Move packages to under new top
         // Must do this after we know parameters and dtypes (as don't clone dtype decls)
@@ -171,7 +171,7 @@ static void process() {
     // Propagate constants into expressions
     V3Const::constifyAllLint(v3Global.rootp());
 
-    if (!v3Global.opt.xmlOnly()) {
+    if (!(v3Global.opt.xmlOnly() && !v3Global.opt.flatten())) {
         // Split packed variables into multiple pieces to resolve UNOPTFLAT.
         // should be after constifyAllLint() which flattens to 1D bit vector
         V3SplitVar::splitVariable(v3Global.rootp());
@@ -215,7 +215,7 @@ static void process() {
 
     //--FLATTENING---------------
 
-    if (!v3Global.opt.xmlOnly()) {
+    if (!(v3Global.opt.xmlOnly() && !v3Global.opt.flatten())) {
         // We're going to flatten the hierarchy, so as many optimizations that
         // can be done as possible should be before this....
 
@@ -228,23 +228,32 @@ static void process() {
         // Flatten hierarchy, creating a SCOPE for each module's usage as a cell
         V3Scope::scopeAll(v3Global.rootp());
         V3LinkDot::linkDotScope(v3Global.rootp());
+
+        // Relocate classes (after linkDot)
+        V3Class::classAll(v3Global.rootp());
     }
 
     //--SCOPE BASED OPTIMIZATIONS--------------
 
-    if (!v3Global.opt.xmlOnly()) {
+    if (!(v3Global.opt.xmlOnly() && !v3Global.opt.flatten())) {
         // Cleanup
         V3Const::constifyAll(v3Global.rootp());
         V3Dead::deadifyDTypesScoped(v3Global.rootp());
         v3Global.checkTree();
+    }
 
+    if (!v3Global.opt.xmlOnly()) {
         // Convert case statements to if() blocks.  Must be after V3Unknown
         // Must be before V3Task so don't need to deal with task in case value compares
         V3Case::caseAll(v3Global.rootp());
+    }
 
+    if (!(v3Global.opt.xmlOnly() && !v3Global.opt.flatten())) {
         // Inline all tasks
         V3Task::taskAll(v3Global.rootp());
+    }
 
+    if (!v3Global.opt.xmlOnly()) {
         // Add __PVT's
         // After V3Task so task internal variables will get renamed
         V3Name::nameAll(v3Global.rootp());
@@ -258,9 +267,7 @@ static void process() {
         // Push constants across variables and remove redundant assignments
         V3Const::constifyAll(v3Global.rootp());
 
-        if (v3Global.opt.oLife()) {
-            V3Life::lifeAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oLife()) V3Life::lifeAll(v3Global.rootp());
 
         // Make large low-fanin logic blocks into lookup tables
         // This should probably be done much later, once we have common logic elimination.
@@ -278,15 +285,11 @@ static void process() {
         V3Active::activeAll(v3Global.rootp());
 
         // Split single ALWAYS blocks into multiple blocks for better ordering chances
-        if (v3Global.opt.oSplit()) {
-            V3Split::splitAlwaysAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oSplit()) V3Split::splitAlwaysAll(v3Global.rootp());
         V3SplitAs::splitAsAll(v3Global.rootp());
 
         // Create tracing sample points, before we start eliminating signals
-        if (v3Global.opt.trace()) {
-            V3TraceDecl::traceDeclAll(v3Global.rootp());
-        }
+        if (v3Global.opt.trace()) V3TraceDecl::traceDeclAll(v3Global.rootp());
 
         // Gate-based logic elimination; eliminate signals and push constant across cell boundaries
         // Instant propagation makes lots-o-constant reduction possibilities.
@@ -294,13 +297,12 @@ static void process() {
             V3Gate::gateAll(v3Global.rootp());
             // V3Gate calls constant propagation itself.
         } else {
-            v3info("Command Line disabled gate optimization with -Og/-O0.  This may cause ordering problems.");
+            v3info("Command Line disabled gate optimization with -Og/-O0.  "
+                   "This may cause ordering problems.");
         }
 
         // Combine COVERINCs with duplicate terms
-        if (v3Global.opt.coverage()) {
-            V3CoverageJoin::coverageJoin(v3Global.rootp());
-        }
+        if (v3Global.opt.coverage()) V3CoverageJoin::coverageJoin(v3Global.rootp());
 
         // Remove unused vars
         V3Const::constifyAll(v3Global.rootp());
@@ -314,9 +316,7 @@ static void process() {
         }
 
         // Reorder assignments in pipelined blocks
-        if (v3Global.opt.oReorder()) {
-            V3Split::splitReorderAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oReorder()) V3Split::splitReorderAll(v3Global.rootp());
 
         // Create delayed assignments
         // This creates lots of duplicate ACTIVES so ActiveTop needs to be after this step
@@ -345,9 +345,7 @@ static void process() {
             V3Const::constifyAll(v3Global.rootp());
             V3Life::lifeAll(v3Global.rootp());
         }
-        if (v3Global.opt.oLifePost()) {
-            V3LifePost::lifepostAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oLifePost()) V3LifePost::lifepostAll(v3Global.rootp());
 
         // Remove unused vars
         V3Const::constifyAll(v3Global.rootp());
@@ -360,9 +358,7 @@ static void process() {
         // Note past this point, we presume traced variables won't move between CFuncs
         // (It's OK if untraced temporaries move around, or vars
         // "effectively" activate the same way.)
-        if (v3Global.opt.trace()) {
-            V3Trace::traceAll(v3Global.rootp());
-        }
+        if (v3Global.opt.trace()) V3Trace::traceAll(v3Global.rootp());
 
         if (v3Global.opt.stats()) V3Stats::statsStageAll(v3Global.rootp(), "Scoped");
 
@@ -379,14 +375,10 @@ static void process() {
         }
 
         // Move BLOCKTEMPS from class to local variables
-        if (v3Global.opt.oLocalize()) {
-            V3Localize::localizeAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oLocalize()) V3Localize::localizeAll(v3Global.rootp());
 
         // Icache packing; combine common code in each module's functions into subroutines
-        if (v3Global.opt.oCombine()) {
-            V3Combine::combineAll(v3Global.rootp());
-        }
+        if (v3Global.opt.oCombine()) V3Combine::combineAll(v3Global.rootp());
     }
 
     V3Error::abortIfErrors();
@@ -410,38 +402,30 @@ static void process() {
     }
 
     // Expand macros and wide operators into C++ primitives
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()
-        && v3Global.opt.oExpand()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly() && v3Global.opt.oExpand()) {
         V3Expand::expandAll(v3Global.rootp());
     }
 
     // Propagate constants across WORDSEL arrayed temporaries
-    if (!v3Global.opt.xmlOnly()
-        && v3Global.opt.oSubst()) {
+    if (!v3Global.opt.xmlOnly() && v3Global.opt.oSubst()) {
         // Constant folding of expanded stuff
         V3Const::constifyCpp(v3Global.rootp());
         V3Subst::substituteAll(v3Global.rootp());
     }
 
-    if (!v3Global.opt.xmlOnly()
-        && v3Global.opt.oSubstConst()) {
+    if (!v3Global.opt.xmlOnly() && v3Global.opt.oSubstConst()) {
         // Constant folding of substitutions
         V3Const::constifyCpp(v3Global.rootp());
-
         V3Dead::deadifyAll(v3Global.rootp());
     }
 
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()
-        && v3Global.opt.oReloop()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly() && v3Global.opt.oReloop()) {
         // Reform loops to reduce code size
         // Must be after all Sel/array index based optimizations
         V3Reloop::reloopAll(v3Global.rootp());
     }
 
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly()) {
         // Fix very deep expressions
         // Mark evaluation functions as member functions, if needed.
         V3Depth::depthAll(v3Global.rootp());
@@ -455,15 +439,12 @@ static void process() {
     }
 
     V3Error::abortIfErrors();
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly()) {  //
         V3CCtors::cctorsAll();
     }
 
     // Output the text
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()
-        && !v3Global.opt.dpiHdrOnly()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly() && !v3Global.opt.dpiHdrOnly()) {
         // Create AstCUse to determine what class forward declarations/#includes needed in C
         // Must be before V3EmitC
         V3CUse::cUseAll(v3Global.rootp());
@@ -475,8 +456,7 @@ static void process() {
     } else if (v3Global.opt.dpiHdrOnly()) {
         V3EmitC::emitcSyms(true);
     }
-    if (!v3Global.opt.xmlOnly()
-        && v3Global.opt.mtasks()) {
+    if (!v3Global.opt.xmlOnly() && v3Global.opt.mtasks()) {
         // Finalize our MTask cost estimates and pack the mtasks into
         // threads. Must happen pre-EmitC which relies on the packing
         // order. Must happen post-V3LifePost which changes the relative
@@ -489,8 +469,7 @@ static void process() {
     }
     if (v3Global.opt.xmlOnly()
         // Check XML when debugging to make sure no missing node types
-        || (v3Global.opt.debugCheck() && !v3Global.opt.lintOnly()
-            && !v3Global.opt.dpiHdrOnly())) {
+        || (v3Global.opt.debugCheck() && !v3Global.opt.lintOnly() && !v3Global.opt.dpiHdrOnly())) {
         V3EmitXml::emitxml();
     }
 
@@ -507,21 +486,116 @@ static void process() {
         V3Stats::statsReport();
     }
 
-    if (!v3Global.opt.lintOnly()
-        && !v3Global.opt.xmlOnly()
-        && !v3Global.opt.dpiHdrOnly()) {
+    if (!v3Global.opt.lintOnly() && !v3Global.opt.xmlOnly() && !v3Global.opt.dpiHdrOnly()) {
         // Makefile must be after all other emitters
-        if (v3Global.opt.cmake()) {
-            V3EmitCMake::emit();
-        }
-        if (v3Global.opt.gmake()) {
-            V3EmitMk::emitmk();
-        }
+        if (v3Global.opt.main()) V3EmitCMain::emit();
+        if (v3Global.opt.cmake()) V3EmitCMake::emit();
+        if (v3Global.opt.gmake()) V3EmitMk::emitmk();
     }
 
     // Note early return above when opt.cdc()
 }
 
+static void verilate(const string& argString) {
+    UINFO(1, "Option --verilate: Start Verilation\n");
+
+    // Can we skip doing everything if times are ok?
+    V3File::addSrcDepend(v3Global.opt.bin());
+    if (v3Global.opt.skipIdentical().isTrue()
+        && V3File::checkTimes(
+            v3Global.opt.makeDir() + "/" + v3Global.opt.prefix() + "__verFiles.dat", argString)) {
+        UINFO(1, "--skip-identical: No change to any source files, exiting\n");
+        return;
+    }
+    // Undocumented debugging - cannot be a switch as then command line
+    // would mismatch forcing non-identicalness when we set it
+    if (!V3Os::getenvStr("VERILATOR_DEBUG_SKIP_IDENTICAL", "").empty()) {
+        v3fatalSrc("VERILATOR_DEBUG_SKIP_IDENTICAL w/ --skip-identical: Changes found\n");
+    }
+
+    //--FRONTEND------------------
+
+    // Cleanup
+    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix() + "_*.tree");
+    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix() + "_*.dot");
+    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix() + "_*.txt");
+
+    // Internal tests (after option parsing as need debug() setting,
+    // and after removing files as may make debug output)
+    AstBasicDTypeKwd::selfTest();
+    if (v3Global.opt.debugSelfTest()) {
+        VHashSha256::selfTest();
+        VSpellCheck::selfTest();
+        V3Graph::selfTest();
+        V3TSP::selfTest();
+        V3ScoreboardBase::selfTest();
+        V3Partition::selfTest();
+    }
+
+    // Read first filename
+    v3Global.readFiles();
+
+    // Link, etc, if needed
+    if (!v3Global.opt.preprocOnly()) {  //
+        process();
+    }
+
+    // Final steps
+    V3Global::dumpCheckGlobalTree("final", 990, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
+    V3Error::abortIfWarnings();
+
+    if (v3Global.opt.makeDepend().isTrue()) {
+        V3File::writeDepend(v3Global.opt.makeDir() + "/" + v3Global.opt.prefix() + "__ver.d");
+    }
+    if (v3Global.opt.protectIds()) {
+        VIdProtect::writeMapFile(v3Global.opt.makeDir() + "/" + v3Global.opt.prefix()
+                                 + "__idmap.xml");
+    }
+    if (v3Global.opt.skipIdentical().isTrue() || v3Global.opt.makeDepend().isTrue()) {
+        V3File::writeTimes(v3Global.opt.makeDir() + "/" + v3Global.opt.prefix() + "__verFiles.dat",
+                           argString);
+    }
+
+    // Final writing shouldn't throw warnings, but...
+    V3Error::abortIfWarnings();
+#ifdef VL_LEAK_CHECKS
+    // Cleanup memory for valgrind leak analysis
+    v3Global.clear();
+#endif
+    FileLine::deleteAllRemaining();
+}
+
+static void execBuildJob() {
+    UASSERT(v3Global.opt.build(), "--build is not specified.");
+    UASSERT(v3Global.opt.gmake(), "--build requires GNU Make.");
+    UASSERT(!v3Global.opt.cmake(), "--build cannot use CMake.");
+    UINFO(1, "Start Build\n");
+
+    const V3StringList& makeFlags = v3Global.opt.makeFlags();
+    const int jobs = v3Global.opt.buildJobs();
+    UASSERT(jobs >= 0, "-j option parser in V3Options.cpp filters out negative value");
+
+    std::stringstream cmd;
+    cmd << v3Global.opt.getenvMAKE();
+    cmd << " -C " << v3Global.opt.makeDir();
+    cmd << " -f " << v3Global.opt.prefix() << ".mk";
+    if (jobs == 0) {
+        cmd << " -j";
+    } else if (jobs > 1) {
+        cmd << " -j " << jobs;
+    }
+    for (V3StringList::const_iterator it = makeFlags.begin(); it != makeFlags.end(); ++it) {
+        cmd << ' ' << *it;
+    }
+
+    const std::string cmdStr = cmd.str();
+    const int exit_code = V3Os::system(cmdStr);
+    if (exit_code != 0) {
+        v3error(cmdStr << " exitted with " << exit_code << std::endl);
+        exit(exit_code);
+    }
+}
+
 //######################################################################
 
 int main(int argc, char** argv, char** env) {
@@ -541,73 +615,22 @@ int main(int argc, char** argv, char** env) {
 
     // Command option parsing
     v3Global.opt.bin(argv[0]);
-    string argString = V3Options::argString(argc-1, argv+1);
-    v3Global.opt.parseOpts(new FileLine(FileLine::commandLineFilename()),
-                           argc-1, argv+1);
+    string argString = V3Options::argString(argc - 1, argv + 1);
+    v3Global.opt.parseOpts(new FileLine(FileLine::commandLineFilename()), argc - 1, argv + 1);
 
     // Validate settings (aka Boost.Program_options)
     v3Global.opt.notify();
+    v3Global.rootp()->timeInit();
 
     V3Error::abortIfErrors();
 
-    // Can we skip doing everything if times are ok?
-    V3File::addSrcDepend(v3Global.opt.bin());
-    if (v3Global.opt.skipIdentical().isTrue()
-        && V3File::checkTimes(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()
-                              +"__verFiles.dat", argString)) {
-        UINFO(1,"--skip-identical: No change to any source files, exiting\n");
-        exit(0);
+    if (v3Global.opt.verilate()) {
+        verilate(argString);
+    } else {
+        UINFO(1, "Option --no-verilate: Skip Verilation\n");
     }
 
-    //--FRONTEND------------------
+    if (v3Global.opt.build()) execBuildJob();
 
-    // Cleanup
-    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix()+"_*.tree");
-    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix()+"_*.dot");
-    V3Os::unlinkRegexp(v3Global.opt.makeDir(), v3Global.opt.prefix()+"_*.txt");
-
-    // Internal tests (after option parsing as need debug() setting,
-    // and after removing files as may make debug output)
-    AstBasicDTypeKwd::selfTest();
-    if (v3Global.opt.debugSelfTest()) {
-        VHashSha256::selfTest();
-        VSpellCheck::selfTest();
-        V3Graph::selfTest();
-        V3TSP::selfTest();
-        V3ScoreboardBase::selfTest();
-        V3Partition::selfTest();
-    }
-
-    // Read first filename
-    v3Global.readFiles();
-
-    // Link, etc, if needed
-    if (!v3Global.opt.preprocOnly()) {
-        process();
-    }
-
-    // Final steps
-    V3Global::dumpCheckGlobalTree("final", 990, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
-    V3Error::abortIfWarnings();
-
-    if (v3Global.opt.makeDepend().isTrue()) {
-        V3File::writeDepend(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"__ver.d");
-    }
-    if (v3Global.opt.skipIdentical().isTrue() || v3Global.opt.makeDepend().isTrue()) {
-        V3File::writeTimes(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()
-                           +"__verFiles.dat", argString);
-    }
-    if (v3Global.opt.protectIds()) {
-        VIdProtect::writeMapFile(v3Global.opt.makeDir()+"/"+v3Global.opt.prefix()+"__idmap.xml");
-    }
-
-    // Final writing shouldn't throw warnings, but...
-    V3Error::abortIfWarnings();
-#ifdef VL_LEAK_CHECKS
-    // Cleanup memory for valgrind leak analysis
-    v3Global.clear();
-#endif
-    FileLine::deleteAllRemaining();
-
-    UINFO(1,"Done, Exiting...\n");
+    UINFO(1, "Done, Exiting...\n");
 }
